"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v5.proto.enums.policy_topic_entry_type_pb2
import google.ads.google_ads.v5.proto.enums.policy_topic_evidence_destination_mismatch_url_type_pb2
import google.ads.google_ads.v5.proto.enums.policy_topic_evidence_destination_not_working_device_pb2
import google.ads.google_ads.v5.proto.enums.policy_topic_evidence_destination_not_working_dns_error_type_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class PolicyViolationKey(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    POLICY_NAME_FIELD_NUMBER: builtins.int
    VIOLATING_TEXT_FIELD_NUMBER: builtins.int
    policy_name: typing.Text = ...
    violating_text: typing.Text = ...
    def __init__(
        self,
        *,
        policy_name: typing.Text = ...,
        violating_text: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_policy_name",
            b"_policy_name",
            "_violating_text",
            b"_violating_text",
            "policy_name",
            b"policy_name",
            "violating_text",
            b"violating_text",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_policy_name",
            b"_policy_name",
            "_violating_text",
            b"_violating_text",
            "policy_name",
            b"policy_name",
            "violating_text",
            b"violating_text",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_policy_name", b"_policy_name"]
    ) -> typing_extensions.Literal["policy_name"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_violating_text", b"_violating_text"],
    ) -> typing_extensions.Literal["violating_text"]: ...

global___PolicyViolationKey = PolicyViolationKey

class PolicyValidationParameter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    IGNORABLE_POLICY_TOPICS_FIELD_NUMBER: builtins.int
    EXEMPT_POLICY_VIOLATION_KEYS_FIELD_NUMBER: builtins.int
    ignorable_policy_topics: google.protobuf.internal.containers.RepeatedScalarFieldContainer[
        typing.Text
    ] = ...
    @property
    def exempt_policy_violation_keys(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___PolicyViolationKey
    ]: ...
    def __init__(
        self,
        *,
        ignorable_policy_topics: typing.Optional[typing.Iterable[typing.Text]] = ...,
        exempt_policy_violation_keys: typing.Optional[
            typing.Iterable[global___PolicyViolationKey]
        ] = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "exempt_policy_violation_keys",
            b"exempt_policy_violation_keys",
            "ignorable_policy_topics",
            b"ignorable_policy_topics",
        ],
    ) -> None: ...

global___PolicyValidationParameter = PolicyValidationParameter

class PolicyTopicEntry(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TOPIC_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    EVIDENCES_FIELD_NUMBER: builtins.int
    CONSTRAINTS_FIELD_NUMBER: builtins.int
    topic: typing.Text = ...
    type: google.ads.google_ads.v5.proto.enums.policy_topic_entry_type_pb2.PolicyTopicEntryTypeEnum.PolicyTopicEntryType.V = (
        ...
    )
    @property
    def evidences(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___PolicyTopicEvidence
    ]: ...
    @property
    def constraints(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___PolicyTopicConstraint
    ]: ...
    def __init__(
        self,
        *,
        topic: typing.Text = ...,
        type: google.ads.google_ads.v5.proto.enums.policy_topic_entry_type_pb2.PolicyTopicEntryTypeEnum.PolicyTopicEntryType.V = ...,
        evidences: typing.Optional[typing.Iterable[global___PolicyTopicEvidence]] = ...,
        constraints: typing.Optional[
            typing.Iterable[global___PolicyTopicConstraint]
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal["_topic", b"_topic", "topic", b"topic"],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_topic",
            b"_topic",
            "constraints",
            b"constraints",
            "evidences",
            b"evidences",
            "topic",
            b"topic",
            "type",
            b"type",
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_topic", b"_topic"]
    ) -> typing_extensions.Literal["topic"]: ...

global___PolicyTopicEntry = PolicyTopicEntry

class PolicyTopicEvidence(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class TextList(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        TEXTS_FIELD_NUMBER: builtins.int
        texts: google.protobuf.internal.containers.RepeatedScalarFieldContainer[
            typing.Text
        ] = ...
        def __init__(
            self,
            *,
            texts: typing.Optional[typing.Iterable[typing.Text]] = ...,
        ) -> None: ...
        def ClearField(
            self, field_name: typing_extensions.Literal["texts", b"texts"]
        ) -> None: ...
    class WebsiteList(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        WEBSITES_FIELD_NUMBER: builtins.int
        websites: google.protobuf.internal.containers.RepeatedScalarFieldContainer[
            typing.Text
        ] = ...
        def __init__(
            self,
            *,
            websites: typing.Optional[typing.Iterable[typing.Text]] = ...,
        ) -> None: ...
        def ClearField(
            self, field_name: typing_extensions.Literal["websites", b"websites"]
        ) -> None: ...
    class DestinationTextList(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        DESTINATION_TEXTS_FIELD_NUMBER: builtins.int
        destination_texts: google.protobuf.internal.containers.RepeatedScalarFieldContainer[
            typing.Text
        ] = ...
        def __init__(
            self,
            *,
            destination_texts: typing.Optional[typing.Iterable[typing.Text]] = ...,
        ) -> None: ...
        def ClearField(
            self,
            field_name: typing_extensions.Literal[
                "destination_texts", b"destination_texts"
            ],
        ) -> None: ...
    class DestinationMismatch(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        URL_TYPES_FIELD_NUMBER: builtins.int
        url_types: google.protobuf.internal.containers.RepeatedScalarFieldContainer[
            google.ads.google_ads.v5.proto.enums.policy_topic_evidence_destination_mismatch_url_type_pb2.PolicyTopicEvidenceDestinationMismatchUrlTypeEnum.PolicyTopicEvidenceDestinationMismatchUrlType.V
        ] = ...
        def __init__(
            self,
            *,
            url_types: typing.Optional[
                typing.Iterable[
                    google.ads.google_ads.v5.proto.enums.policy_topic_evidence_destination_mismatch_url_type_pb2.PolicyTopicEvidenceDestinationMismatchUrlTypeEnum.PolicyTopicEvidenceDestinationMismatchUrlType.V
                ]
            ] = ...,
        ) -> None: ...
        def ClearField(
            self, field_name: typing_extensions.Literal["url_types", b"url_types"]
        ) -> None: ...
    class DestinationNotWorking(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        EXPANDED_URL_FIELD_NUMBER: builtins.int
        DEVICE_FIELD_NUMBER: builtins.int
        LAST_CHECKED_DATE_TIME_FIELD_NUMBER: builtins.int
        DNS_ERROR_TYPE_FIELD_NUMBER: builtins.int
        HTTP_ERROR_CODE_FIELD_NUMBER: builtins.int
        expanded_url: typing.Text = ...
        device: google.ads.google_ads.v5.proto.enums.policy_topic_evidence_destination_not_working_device_pb2.PolicyTopicEvidenceDestinationNotWorkingDeviceEnum.PolicyTopicEvidenceDestinationNotWorkingDevice.V = (
            ...
        )
        last_checked_date_time: typing.Text = ...
        dns_error_type: google.ads.google_ads.v5.proto.enums.policy_topic_evidence_destination_not_working_dns_error_type_pb2.PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum.PolicyTopicEvidenceDestinationNotWorkingDnsErrorType.V = (
            ...
        )
        http_error_code: builtins.int = ...
        def __init__(
            self,
            *,
            expanded_url: typing.Text = ...,
            device: google.ads.google_ads.v5.proto.enums.policy_topic_evidence_destination_not_working_device_pb2.PolicyTopicEvidenceDestinationNotWorkingDeviceEnum.PolicyTopicEvidenceDestinationNotWorkingDevice.V = ...,
            last_checked_date_time: typing.Text = ...,
            dns_error_type: google.ads.google_ads.v5.proto.enums.policy_topic_evidence_destination_not_working_dns_error_type_pb2.PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum.PolicyTopicEvidenceDestinationNotWorkingDnsErrorType.V = ...,
            http_error_code: builtins.int = ...,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing_extensions.Literal[
                "_expanded_url",
                b"_expanded_url",
                "_last_checked_date_time",
                b"_last_checked_date_time",
                "dns_error_type",
                b"dns_error_type",
                "expanded_url",
                b"expanded_url",
                "http_error_code",
                b"http_error_code",
                "last_checked_date_time",
                b"last_checked_date_time",
                "reason",
                b"reason",
            ],
        ) -> builtins.bool: ...
        def ClearField(
            self,
            field_name: typing_extensions.Literal[
                "_expanded_url",
                b"_expanded_url",
                "_last_checked_date_time",
                b"_last_checked_date_time",
                "device",
                b"device",
                "dns_error_type",
                b"dns_error_type",
                "expanded_url",
                b"expanded_url",
                "http_error_code",
                b"http_error_code",
                "last_checked_date_time",
                b"last_checked_date_time",
                "reason",
                b"reason",
            ],
        ) -> None: ...
        @typing.overload
        def WhichOneof(
            self,
            oneof_group: typing_extensions.Literal["_expanded_url", b"_expanded_url"],
        ) -> typing_extensions.Literal["expanded_url"]: ...
        @typing.overload
        def WhichOneof(
            self,
            oneof_group: typing_extensions.Literal[
                "_last_checked_date_time", b"_last_checked_date_time"
            ],
        ) -> typing_extensions.Literal["last_checked_date_time"]: ...
        @typing.overload
        def WhichOneof(
            self, oneof_group: typing_extensions.Literal["reason", b"reason"]
        ) -> typing_extensions.Literal["dns_error_type", "http_error_code"]: ...
    WEBSITE_LIST_FIELD_NUMBER: builtins.int
    TEXT_LIST_FIELD_NUMBER: builtins.int
    LANGUAGE_CODE_FIELD_NUMBER: builtins.int
    DESTINATION_TEXT_LIST_FIELD_NUMBER: builtins.int
    DESTINATION_MISMATCH_FIELD_NUMBER: builtins.int
    DESTINATION_NOT_WORKING_FIELD_NUMBER: builtins.int
    language_code: typing.Text = ...
    @property
    def website_list(self) -> global___PolicyTopicEvidence.WebsiteList: ...
    @property
    def text_list(self) -> global___PolicyTopicEvidence.TextList: ...
    @property
    def destination_text_list(
        self,
    ) -> global___PolicyTopicEvidence.DestinationTextList: ...
    @property
    def destination_mismatch(
        self,
    ) -> global___PolicyTopicEvidence.DestinationMismatch: ...
    @property
    def destination_not_working(
        self,
    ) -> global___PolicyTopicEvidence.DestinationNotWorking: ...
    def __init__(
        self,
        *,
        website_list: typing.Optional[global___PolicyTopicEvidence.WebsiteList] = ...,
        text_list: typing.Optional[global___PolicyTopicEvidence.TextList] = ...,
        language_code: typing.Text = ...,
        destination_text_list: typing.Optional[
            global___PolicyTopicEvidence.DestinationTextList
        ] = ...,
        destination_mismatch: typing.Optional[
            global___PolicyTopicEvidence.DestinationMismatch
        ] = ...,
        destination_not_working: typing.Optional[
            global___PolicyTopicEvidence.DestinationNotWorking
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "destination_mismatch",
            b"destination_mismatch",
            "destination_not_working",
            b"destination_not_working",
            "destination_text_list",
            b"destination_text_list",
            "language_code",
            b"language_code",
            "text_list",
            b"text_list",
            "value",
            b"value",
            "website_list",
            b"website_list",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "destination_mismatch",
            b"destination_mismatch",
            "destination_not_working",
            b"destination_not_working",
            "destination_text_list",
            b"destination_text_list",
            "language_code",
            b"language_code",
            "text_list",
            b"text_list",
            "value",
            b"value",
            "website_list",
            b"website_list",
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["value", b"value"]
    ) -> typing_extensions.Literal[
        "website_list",
        "text_list",
        "language_code",
        "destination_text_list",
        "destination_mismatch",
        "destination_not_working",
    ]: ...

global___PolicyTopicEvidence = PolicyTopicEvidence

class PolicyTopicConstraint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class CountryConstraintList(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        TOTAL_TARGETED_COUNTRIES_FIELD_NUMBER: builtins.int
        COUNTRIES_FIELD_NUMBER: builtins.int
        total_targeted_countries: builtins.int = ...
        @property
        def countries(
            self,
        ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
            global___PolicyTopicConstraint.CountryConstraint
        ]: ...
        def __init__(
            self,
            *,
            total_targeted_countries: builtins.int = ...,
            countries: typing.Optional[
                typing.Iterable[global___PolicyTopicConstraint.CountryConstraint]
            ] = ...,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing_extensions.Literal[
                "_total_targeted_countries",
                b"_total_targeted_countries",
                "total_targeted_countries",
                b"total_targeted_countries",
            ],
        ) -> builtins.bool: ...
        def ClearField(
            self,
            field_name: typing_extensions.Literal[
                "_total_targeted_countries",
                b"_total_targeted_countries",
                "countries",
                b"countries",
                "total_targeted_countries",
                b"total_targeted_countries",
            ],
        ) -> None: ...
        def WhichOneof(
            self,
            oneof_group: typing_extensions.Literal[
                "_total_targeted_countries", b"_total_targeted_countries"
            ],
        ) -> typing_extensions.Literal["total_targeted_countries"]: ...
    class ResellerConstraint(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        def __init__(
            self,
        ) -> None: ...
    class CountryConstraint(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        COUNTRY_CRITERION_FIELD_NUMBER: builtins.int
        country_criterion: typing.Text = ...
        def __init__(
            self,
            *,
            country_criterion: typing.Text = ...,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing_extensions.Literal[
                "_country_criterion",
                b"_country_criterion",
                "country_criterion",
                b"country_criterion",
            ],
        ) -> builtins.bool: ...
        def ClearField(
            self,
            field_name: typing_extensions.Literal[
                "_country_criterion",
                b"_country_criterion",
                "country_criterion",
                b"country_criterion",
            ],
        ) -> None: ...
        def WhichOneof(
            self,
            oneof_group: typing_extensions.Literal[
                "_country_criterion", b"_country_criterion"
            ],
        ) -> typing_extensions.Literal["country_criterion"]: ...
    COUNTRY_CONSTRAINT_LIST_FIELD_NUMBER: builtins.int
    RESELLER_CONSTRAINT_FIELD_NUMBER: builtins.int
    CERTIFICATE_MISSING_IN_COUNTRY_LIST_FIELD_NUMBER: builtins.int
    CERTIFICATE_DOMAIN_MISMATCH_IN_COUNTRY_LIST_FIELD_NUMBER: builtins.int
    @property
    def country_constraint_list(
        self,
    ) -> global___PolicyTopicConstraint.CountryConstraintList: ...
    @property
    def reseller_constraint(
        self,
    ) -> global___PolicyTopicConstraint.ResellerConstraint: ...
    @property
    def certificate_missing_in_country_list(
        self,
    ) -> global___PolicyTopicConstraint.CountryConstraintList: ...
    @property
    def certificate_domain_mismatch_in_country_list(
        self,
    ) -> global___PolicyTopicConstraint.CountryConstraintList: ...
    def __init__(
        self,
        *,
        country_constraint_list: typing.Optional[
            global___PolicyTopicConstraint.CountryConstraintList
        ] = ...,
        reseller_constraint: typing.Optional[
            global___PolicyTopicConstraint.ResellerConstraint
        ] = ...,
        certificate_missing_in_country_list: typing.Optional[
            global___PolicyTopicConstraint.CountryConstraintList
        ] = ...,
        certificate_domain_mismatch_in_country_list: typing.Optional[
            global___PolicyTopicConstraint.CountryConstraintList
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "certificate_domain_mismatch_in_country_list",
            b"certificate_domain_mismatch_in_country_list",
            "certificate_missing_in_country_list",
            b"certificate_missing_in_country_list",
            "country_constraint_list",
            b"country_constraint_list",
            "reseller_constraint",
            b"reseller_constraint",
            "value",
            b"value",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "certificate_domain_mismatch_in_country_list",
            b"certificate_domain_mismatch_in_country_list",
            "certificate_missing_in_country_list",
            b"certificate_missing_in_country_list",
            "country_constraint_list",
            b"country_constraint_list",
            "reseller_constraint",
            b"reseller_constraint",
            "value",
            b"value",
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["value", b"value"]
    ) -> typing_extensions.Literal[
        "country_constraint_list",
        "reseller_constraint",
        "certificate_missing_in_country_list",
        "certificate_domain_mismatch_in_country_list",
    ]: ...

global___PolicyTopicConstraint = PolicyTopicConstraint



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ConversionActionTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _ConversionActionType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            ConversionActionType.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = ConversionActionTypeEnum.ConversionActionType.V(0)
        UNKNOWN = ConversionActionTypeEnum.ConversionActionType.V(1)
        AD_CALL = ConversionActionTypeEnum.ConversionActionType.V(2)
        CLICK_TO_CALL = ConversionActionTypeEnum.ConversionActionType.V(3)
        GOOGLE_PLAY_DOWNLOAD = ConversionActionTypeEnum.ConversionActionType.V(4)
        GOOGLE_PLAY_IN_APP_PURCHASE = ConversionActionTypeEnum.ConversionActionType.V(5)
        UPLOAD_CALLS = ConversionActionTypeEnum.ConversionActionType.V(6)
        UPLOAD_CLICKS = ConversionActionTypeEnum.ConversionActionType.V(7)
        WEBPAGE = ConversionActionTypeEnum.ConversionActionType.V(8)
        WEBSITE_CALL = ConversionActionTypeEnum.ConversionActionType.V(9)
        STORE_SALES_DIRECT_UPLOAD = ConversionActionTypeEnum.ConversionActionType.V(10)
        STORE_SALES = ConversionActionTypeEnum.ConversionActionType.V(11)
        FIREBASE_ANDROID_FIRST_OPEN = ConversionActionTypeEnum.ConversionActionType.V(
            12
        )
        FIREBASE_ANDROID_IN_APP_PURCHASE = (
            ConversionActionTypeEnum.ConversionActionType.V(13)
        )
        FIREBASE_ANDROID_CUSTOM = ConversionActionTypeEnum.ConversionActionType.V(14)
        FIREBASE_IOS_FIRST_OPEN = ConversionActionTypeEnum.ConversionActionType.V(15)
        FIREBASE_IOS_IN_APP_PURCHASE = ConversionActionTypeEnum.ConversionActionType.V(
            16
        )
        FIREBASE_IOS_CUSTOM = ConversionActionTypeEnum.ConversionActionType.V(17)
        THIRD_PARTY_APP_ANALYTICS_ANDROID_FIRST_OPEN = (
            ConversionActionTypeEnum.ConversionActionType.V(18)
        )
        THIRD_PARTY_APP_ANALYTICS_ANDROID_IN_APP_PURCHASE = (
            ConversionActionTypeEnum.ConversionActionType.V(19)
        )
        THIRD_PARTY_APP_ANALYTICS_ANDROID_CUSTOM = (
            ConversionActionTypeEnum.ConversionActionType.V(20)
        )
        THIRD_PARTY_APP_ANALYTICS_IOS_FIRST_OPEN = (
            ConversionActionTypeEnum.ConversionActionType.V(21)
        )
        THIRD_PARTY_APP_ANALYTICS_IOS_IN_APP_PURCHASE = (
            ConversionActionTypeEnum.ConversionActionType.V(22)
        )
        THIRD_PARTY_APP_ANALYTICS_IOS_CUSTOM = (
            ConversionActionTypeEnum.ConversionActionType.V(23)
        )
    class ConversionActionType(metaclass=_ConversionActionType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = ConversionActionTypeEnum.ConversionActionType.V(0)
    UNKNOWN = ConversionActionTypeEnum.ConversionActionType.V(1)
    AD_CALL = ConversionActionTypeEnum.ConversionActionType.V(2)
    CLICK_TO_CALL = ConversionActionTypeEnum.ConversionActionType.V(3)
    GOOGLE_PLAY_DOWNLOAD = ConversionActionTypeEnum.ConversionActionType.V(4)
    GOOGLE_PLAY_IN_APP_PURCHASE = ConversionActionTypeEnum.ConversionActionType.V(5)
    UPLOAD_CALLS = ConversionActionTypeEnum.ConversionActionType.V(6)
    UPLOAD_CLICKS = ConversionActionTypeEnum.ConversionActionType.V(7)
    WEBPAGE = ConversionActionTypeEnum.ConversionActionType.V(8)
    WEBSITE_CALL = ConversionActionTypeEnum.ConversionActionType.V(9)
    STORE_SALES_DIRECT_UPLOAD = ConversionActionTypeEnum.ConversionActionType.V(10)
    STORE_SALES = ConversionActionTypeEnum.ConversionActionType.V(11)
    FIREBASE_ANDROID_FIRST_OPEN = ConversionActionTypeEnum.ConversionActionType.V(12)
    FIREBASE_ANDROID_IN_APP_PURCHASE = ConversionActionTypeEnum.ConversionActionType.V(
        13
    )
    FIREBASE_ANDROID_CUSTOM = ConversionActionTypeEnum.ConversionActionType.V(14)
    FIREBASE_IOS_FIRST_OPEN = ConversionActionTypeEnum.ConversionActionType.V(15)
    FIREBASE_IOS_IN_APP_PURCHASE = ConversionActionTypeEnum.ConversionActionType.V(16)
    FIREBASE_IOS_CUSTOM = ConversionActionTypeEnum.ConversionActionType.V(17)
    THIRD_PARTY_APP_ANALYTICS_ANDROID_FIRST_OPEN = (
        ConversionActionTypeEnum.ConversionActionType.V(18)
    )
    THIRD_PARTY_APP_ANALYTICS_ANDROID_IN_APP_PURCHASE = (
        ConversionActionTypeEnum.ConversionActionType.V(19)
    )
    THIRD_PARTY_APP_ANALYTICS_ANDROID_CUSTOM = (
        ConversionActionTypeEnum.ConversionActionType.V(20)
    )
    THIRD_PARTY_APP_ANALYTICS_IOS_FIRST_OPEN = (
        ConversionActionTypeEnum.ConversionActionType.V(21)
    )
    THIRD_PARTY_APP_ANALYTICS_IOS_IN_APP_PURCHASE = (
        ConversionActionTypeEnum.ConversionActionType.V(22)
    )
    THIRD_PARTY_APP_ANALYTICS_IOS_CUSTOM = (
        ConversionActionTypeEnum.ConversionActionType.V(23)
    )
    def __init__(
        self,
    ) -> None: ...

global___ConversionActionTypeEnum = ConversionActionTypeEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class NewResourceCreationErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _NewResourceCreationError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            NewResourceCreationError.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = NewResourceCreationErrorEnum.NewResourceCreationError.V(0)
        UNKNOWN = NewResourceCreationErrorEnum.NewResourceCreationError.V(1)
        CANNOT_SET_ID_FOR_CREATE = (
            NewResourceCreationErrorEnum.NewResourceCreationError.V(2)
        )
        DUPLICATE_TEMP_IDS = NewResourceCreationErrorEnum.NewResourceCreationError.V(3)
        TEMP_ID_RESOURCE_HAD_ERRORS = (
            NewResourceCreationErrorEnum.NewResourceCreationError.V(4)
        )
    class NewResourceCreationError(metaclass=_NewResourceCreationError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = NewResourceCreationErrorEnum.NewResourceCreationError.V(0)
    UNKNOWN = NewResourceCreationErrorEnum.NewResourceCreationError.V(1)
    CANNOT_SET_ID_FOR_CREATE = NewResourceCreationErrorEnum.NewResourceCreationError.V(
        2
    )
    DUPLICATE_TEMP_IDS = NewResourceCreationErrorEnum.NewResourceCreationError.V(3)
    TEMP_ID_RESOURCE_HAD_ERRORS = (
        NewResourceCreationErrorEnum.NewResourceCreationError.V(4)
    )
    def __init__(
        self,
    ) -> None: ...

global___NewResourceCreationErrorEnum = NewResourceCreationErrorEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v5.proto.resources.campaign_pb2
import grpc

from .campaign_service_pb2 import *

class CampaignServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetCampaign(
        self,
        request: global___GetCampaignRequest,
    ) -> google.ads.google_ads.v5.proto.resources.campaign_pb2.Campaign: ...
    def MutateCampaigns(
        self,
        request: global___MutateCampaignsRequest,
    ) -> global___MutateCampaignsResponse: ...

class CampaignServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetCampaign(
        self,
        request: global___GetCampaignRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v5.proto.resources.campaign_pb2.Campaign: ...
    @abc.abstractmethod
    def MutateCampaigns(
        self,
        request: global___MutateCampaignsRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateCampaignsResponse: ...

def add_CampaignServiceServicer_to_server(
    servicer: CampaignServiceServicer, server: grpc.Server
) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class AccessInvitationErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _AccessInvitationError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            AccessInvitationError.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = AccessInvitationErrorEnum.AccessInvitationError.V(0)
        UNKNOWN = AccessInvitationErrorEnum.AccessInvitationError.V(1)
        INVALID_EMAIL_ADDRESS = AccessInvitationErrorEnum.AccessInvitationError.V(2)
        EMAIL_ADDRESS_ALREADY_HAS_ACCESS = (
            AccessInvitationErrorEnum.AccessInvitationError.V(3)
        )
        INVALID_INVITATION_STATUS = AccessInvitationErrorEnum.AccessInvitationError.V(4)
        GOOGLE_CONSUMER_ACCOUNT_NOT_ALLOWED = (
            AccessInvitationErrorEnum.AccessInvitationError.V(5)
        )
        INVALID_INVITATION_ID = AccessInvitationErrorEnum.AccessInvitationError.V(6)
        EMAIL_ADDRESS_ALREADY_HAS_PENDING_INVITATION = (
            AccessInvitationErrorEnum.AccessInvitationError.V(7)
        )
        PENDING_INVITATIONS_LIMIT_EXCEEDED = (
            AccessInvitationErrorEnum.AccessInvitationError.V(8)
        )
    class AccessInvitationError(metaclass=_AccessInvitationError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = AccessInvitationErrorEnum.AccessInvitationError.V(0)
    UNKNOWN = AccessInvitationErrorEnum.AccessInvitationError.V(1)
    INVALID_EMAIL_ADDRESS = AccessInvitationErrorEnum.AccessInvitationError.V(2)
    EMAIL_ADDRESS_ALREADY_HAS_ACCESS = (
        AccessInvitationErrorEnum.AccessInvitationError.V(3)
    )
    INVALID_INVITATION_STATUS = AccessInvitationErrorEnum.AccessInvitationError.V(4)
    GOOGLE_CONSUMER_ACCOUNT_NOT_ALLOWED = (
        AccessInvitationErrorEnum.AccessInvitationError.V(5)
    )
    INVALID_INVITATION_ID = AccessInvitationErrorEnum.AccessInvitationError.V(6)
    EMAIL_ADDRESS_ALREADY_HAS_PENDING_INVITATION = (
        AccessInvitationErrorEnum.AccessInvitationError.V(7)
    )
    PENDING_INVITATIONS_LIMIT_EXCEEDED = (
        AccessInvitationErrorEnum.AccessInvitationError.V(8)
    )
    def __init__(
        self,
    ) -> None: ...

global___AccessInvitationErrorEnum = AccessInvitationErrorEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CriterionErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _CriterionError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[CriterionError.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = CriterionErrorEnum.CriterionError.V(0)
        UNKNOWN = CriterionErrorEnum.CriterionError.V(1)
        CONCRETE_TYPE_REQUIRED = CriterionErrorEnum.CriterionError.V(2)
        INVALID_EXCLUDED_CATEGORY = CriterionErrorEnum.CriterionError.V(3)
        INVALID_KEYWORD_TEXT = CriterionErrorEnum.CriterionError.V(4)
        KEYWORD_TEXT_TOO_LONG = CriterionErrorEnum.CriterionError.V(5)
        KEYWORD_HAS_TOO_MANY_WORDS = CriterionErrorEnum.CriterionError.V(6)
        KEYWORD_HAS_INVALID_CHARS = CriterionErrorEnum.CriterionError.V(7)
        INVALID_PLACEMENT_URL = CriterionErrorEnum.CriterionError.V(8)
        INVALID_USER_LIST = CriterionErrorEnum.CriterionError.V(9)
        INVALID_USER_INTEREST = CriterionErrorEnum.CriterionError.V(10)
        INVALID_FORMAT_FOR_PLACEMENT_URL = CriterionErrorEnum.CriterionError.V(11)
        PLACEMENT_URL_IS_TOO_LONG = CriterionErrorEnum.CriterionError.V(12)
        PLACEMENT_URL_HAS_ILLEGAL_CHAR = CriterionErrorEnum.CriterionError.V(13)
        PLACEMENT_URL_HAS_MULTIPLE_SITES_IN_LINE = CriterionErrorEnum.CriterionError.V(
            14
        )
        PLACEMENT_IS_NOT_AVAILABLE_FOR_TARGETING_OR_EXCLUSION = (
            CriterionErrorEnum.CriterionError.V(15)
        )
        INVALID_TOPIC_PATH = CriterionErrorEnum.CriterionError.V(16)
        INVALID_YOUTUBE_CHANNEL_ID = CriterionErrorEnum.CriterionError.V(17)
        INVALID_YOUTUBE_VIDEO_ID = CriterionErrorEnum.CriterionError.V(18)
        YOUTUBE_VERTICAL_CHANNEL_DEPRECATED = CriterionErrorEnum.CriterionError.V(19)
        YOUTUBE_DEMOGRAPHIC_CHANNEL_DEPRECATED = CriterionErrorEnum.CriterionError.V(20)
        YOUTUBE_URL_UNSUPPORTED = CriterionErrorEnum.CriterionError.V(21)
        CANNOT_EXCLUDE_CRITERIA_TYPE = CriterionErrorEnum.CriterionError.V(22)
        CANNOT_ADD_CRITERIA_TYPE = CriterionErrorEnum.CriterionError.V(23)
        CANNOT_EXCLUDE_SIMILAR_USER_LIST = CriterionErrorEnum.CriterionError.V(26)
        CANNOT_ADD_CLOSED_USER_LIST = CriterionErrorEnum.CriterionError.V(27)
        CANNOT_ADD_DISPLAY_ONLY_LISTS_TO_SEARCH_ONLY_CAMPAIGNS = (
            CriterionErrorEnum.CriterionError.V(28)
        )
        CANNOT_ADD_DISPLAY_ONLY_LISTS_TO_SEARCH_CAMPAIGNS = (
            CriterionErrorEnum.CriterionError.V(29)
        )
        CANNOT_ADD_DISPLAY_ONLY_LISTS_TO_SHOPPING_CAMPAIGNS = (
            CriterionErrorEnum.CriterionError.V(30)
        )
        CANNOT_ADD_USER_INTERESTS_TO_SEARCH_CAMPAIGNS = (
            CriterionErrorEnum.CriterionError.V(31)
        )
        CANNOT_SET_BIDS_ON_CRITERION_TYPE_IN_SEARCH_CAMPAIGNS = (
            CriterionErrorEnum.CriterionError.V(32)
        )
        CANNOT_ADD_URLS_TO_CRITERION_TYPE_FOR_CAMPAIGN_TYPE = (
            CriterionErrorEnum.CriterionError.V(33)
        )
        INVALID_COMBINED_AUDIENCE = CriterionErrorEnum.CriterionError.V(122)
        INVALID_CUSTOM_AFFINITY = CriterionErrorEnum.CriterionError.V(96)
        INVALID_CUSTOM_INTENT = CriterionErrorEnum.CriterionError.V(97)
        INVALID_CUSTOM_AUDIENCE = CriterionErrorEnum.CriterionError.V(121)
        INVALID_IP_ADDRESS = CriterionErrorEnum.CriterionError.V(34)
        INVALID_IP_FORMAT = CriterionErrorEnum.CriterionError.V(35)
        INVALID_MOBILE_APP = CriterionErrorEnum.CriterionError.V(36)
        INVALID_MOBILE_APP_CATEGORY = CriterionErrorEnum.CriterionError.V(37)
        INVALID_CRITERION_ID = CriterionErrorEnum.CriterionError.V(38)
        CANNOT_TARGET_CRITERION = CriterionErrorEnum.CriterionError.V(39)
        CANNOT_TARGET_OBSOLETE_CRITERION = CriterionErrorEnum.CriterionError.V(40)
        CRITERION_ID_AND_TYPE_MISMATCH = CriterionErrorEnum.CriterionError.V(41)
        INVALID_PROXIMITY_RADIUS = CriterionErrorEnum.CriterionError.V(42)
        INVALID_PROXIMITY_RADIUS_UNITS = CriterionErrorEnum.CriterionError.V(43)
        INVALID_STREETADDRESS_LENGTH = CriterionErrorEnum.CriterionError.V(44)
        INVALID_CITYNAME_LENGTH = CriterionErrorEnum.CriterionError.V(45)
        INVALID_REGIONCODE_LENGTH = CriterionErrorEnum.CriterionError.V(46)
        INVALID_REGIONNAME_LENGTH = CriterionErrorEnum.CriterionError.V(47)
        INVALID_POSTALCODE_LENGTH = CriterionErrorEnum.CriterionError.V(48)
        INVALID_COUNTRY_CODE = CriterionErrorEnum.CriterionError.V(49)
        INVALID_LATITUDE = CriterionErrorEnum.CriterionError.V(50)
        INVALID_LONGITUDE = CriterionErrorEnum.CriterionError.V(51)
        PROXIMITY_GEOPOINT_AND_ADDRESS_BOTH_CANNOT_BE_NULL = (
            CriterionErrorEnum.CriterionError.V(52)
        )
        INVALID_PROXIMITY_ADDRESS = CriterionErrorEnum.CriterionError.V(53)
        INVALID_USER_DOMAIN_NAME = CriterionErrorEnum.CriterionError.V(54)
        CRITERION_PARAMETER_TOO_LONG = CriterionErrorEnum.CriterionError.V(55)
        AD_SCHEDULE_TIME_INTERVALS_OVERLAP = CriterionErrorEnum.CriterionError.V(56)
        AD_SCHEDULE_INTERVAL_CANNOT_SPAN_MULTIPLE_DAYS = (
            CriterionErrorEnum.CriterionError.V(57)
        )
        AD_SCHEDULE_INVALID_TIME_INTERVAL = CriterionErrorEnum.CriterionError.V(58)
        AD_SCHEDULE_EXCEEDED_INTERVALS_PER_DAY_LIMIT = (
            CriterionErrorEnum.CriterionError.V(59)
        )
        AD_SCHEDULE_CRITERION_ID_MISMATCHING_FIELDS = (
            CriterionErrorEnum.CriterionError.V(60)
        )
        CANNOT_BID_MODIFY_CRITERION_TYPE = CriterionErrorEnum.CriterionError.V(61)
        CANNOT_BID_MODIFY_CRITERION_CAMPAIGN_OPTED_OUT = (
            CriterionErrorEnum.CriterionError.V(62)
        )
        CANNOT_BID_MODIFY_NEGATIVE_CRITERION = CriterionErrorEnum.CriterionError.V(63)
        BID_MODIFIER_ALREADY_EXISTS = CriterionErrorEnum.CriterionError.V(64)
        FEED_ID_NOT_ALLOWED = CriterionErrorEnum.CriterionError.V(65)
        ACCOUNT_INELIGIBLE_FOR_CRITERIA_TYPE = CriterionErrorEnum.CriterionError.V(66)
        CRITERIA_TYPE_INVALID_FOR_BIDDING_STRATEGY = (
            CriterionErrorEnum.CriterionError.V(67)
        )
        CANNOT_EXCLUDE_CRITERION = CriterionErrorEnum.CriterionError.V(68)
        CANNOT_REMOVE_CRITERION = CriterionErrorEnum.CriterionError.V(69)
        INVALID_PRODUCT_BIDDING_CATEGORY = CriterionErrorEnum.CriterionError.V(76)
        MISSING_SHOPPING_SETTING = CriterionErrorEnum.CriterionError.V(77)
        INVALID_MATCHING_FUNCTION = CriterionErrorEnum.CriterionError.V(78)
        LOCATION_FILTER_NOT_ALLOWED = CriterionErrorEnum.CriterionError.V(79)
        INVALID_FEED_FOR_LOCATION_FILTER = CriterionErrorEnum.CriterionError.V(98)
        LOCATION_FILTER_INVALID = CriterionErrorEnum.CriterionError.V(80)
        CANNOT_SET_GEO_TARGET_CONSTANTS_WITH_FEED_ITEM_SETS = (
            CriterionErrorEnum.CriterionError.V(123)
        )
        INVALID_LOCATION_GROUP_RADIUS = CriterionErrorEnum.CriterionError.V(124)
        INVALID_LOCATION_GROUP_RADIUS_UNIT = CriterionErrorEnum.CriterionError.V(125)
        CANNOT_ATTACH_CRITERIA_AT_CAMPAIGN_AND_ADGROUP = (
            CriterionErrorEnum.CriterionError.V(81)
        )
        HOTEL_LENGTH_OF_STAY_OVERLAPS_WITH_EXISTING_CRITERION = (
            CriterionErrorEnum.CriterionError.V(82)
        )
        HOTEL_ADVANCE_BOOKING_WINDOW_OVERLAPS_WITH_EXISTING_CRITERION = (
            CriterionErrorEnum.CriterionError.V(83)
        )
        FIELD_INCOMPATIBLE_WITH_NEGATIVE_TARGETING = (
            CriterionErrorEnum.CriterionError.V(84)
        )
        INVALID_WEBPAGE_CONDITION = CriterionErrorEnum.CriterionError.V(85)
        INVALID_WEBPAGE_CONDITION_URL = CriterionErrorEnum.CriterionError.V(86)
        WEBPAGE_CONDITION_URL_CANNOT_BE_EMPTY = CriterionErrorEnum.CriterionError.V(87)
        WEBPAGE_CONDITION_URL_UNSUPPORTED_PROTOCOL = (
            CriterionErrorEnum.CriterionError.V(88)
        )
        WEBPAGE_CONDITION_URL_CANNOT_BE_IP_ADDRESS = (
            CriterionErrorEnum.CriterionError.V(89)
        )
        WEBPAGE_CONDITION_URL_DOMAIN_NOT_CONSISTENT_WITH_CAMPAIGN_SETTING = (
            CriterionErrorEnum.CriterionError.V(90)
        )
        WEBPAGE_CONDITION_URL_CANNOT_BE_PUBLIC_SUFFIX = (
            CriterionErrorEnum.CriterionError.V(91)
        )
        WEBPAGE_CONDITION_URL_INVALID_PUBLIC_SUFFIX = (
            CriterionErrorEnum.CriterionError.V(92)
        )
        WEBPAGE_CONDITION_URL_VALUE_TRACK_VALUE_NOT_SUPPORTED = (
            CriterionErrorEnum.CriterionError.V(93)
        )
        WEBPAGE_CRITERION_URL_EQUALS_CAN_HAVE_ONLY_ONE_CONDITION = (
            CriterionErrorEnum.CriterionError.V(94)
        )
        WEBPAGE_CRITERION_NOT_SUPPORTED_ON_NON_DSA_AD_GROUP = (
            CriterionErrorEnum.CriterionError.V(95)
        )
        CANNOT_TARGET_USER_LIST_FOR_SMART_DISPLAY_CAMPAIGNS = (
            CriterionErrorEnum.CriterionError.V(99)
        )
        CANNOT_TARGET_PLACEMENTS_FOR_SEARCH_CAMPAIGNS = (
            CriterionErrorEnum.CriterionError.V(126)
        )
        LISTING_SCOPE_TOO_MANY_DIMENSION_TYPES = CriterionErrorEnum.CriterionError.V(
            100
        )
        LISTING_SCOPE_TOO_MANY_IN_OPERATORS = CriterionErrorEnum.CriterionError.V(101)
        LISTING_SCOPE_IN_OPERATOR_NOT_SUPPORTED = CriterionErrorEnum.CriterionError.V(
            102
        )
        DUPLICATE_LISTING_DIMENSION_TYPE = CriterionErrorEnum.CriterionError.V(103)
        DUPLICATE_LISTING_DIMENSION_VALUE = CriterionErrorEnum.CriterionError.V(104)
        CANNOT_SET_BIDS_ON_LISTING_GROUP_SUBDIVISION = (
            CriterionErrorEnum.CriterionError.V(105)
        )
        INVALID_LISTING_GROUP_HIERARCHY = CriterionErrorEnum.CriterionError.V(106)
        LISTING_GROUP_UNIT_CANNOT_HAVE_CHILDREN = CriterionErrorEnum.CriterionError.V(
            107
        )
        LISTING_GROUP_SUBDIVISION_REQUIRES_OTHERS_CASE = (
            CriterionErrorEnum.CriterionError.V(108)
        )
        LISTING_GROUP_REQUIRES_SAME_DIMENSION_TYPE_AS_SIBLINGS = (
            CriterionErrorEnum.CriterionError.V(109)
        )
        LISTING_GROUP_ALREADY_EXISTS = CriterionErrorEnum.CriterionError.V(110)
        LISTING_GROUP_DOES_NOT_EXIST = CriterionErrorEnum.CriterionError.V(111)
        LISTING_GROUP_CANNOT_BE_REMOVED = CriterionErrorEnum.CriterionError.V(112)
        INVALID_LISTING_GROUP_TYPE = CriterionErrorEnum.CriterionError.V(113)
        LISTING_GROUP_ADD_MAY_ONLY_USE_TEMP_ID = CriterionErrorEnum.CriterionError.V(
            114
        )
        LISTING_SCOPE_TOO_LONG = CriterionErrorEnum.CriterionError.V(115)
        LISTING_SCOPE_TOO_MANY_DIMENSIONS = CriterionErrorEnum.CriterionError.V(116)
        LISTING_GROUP_TOO_LONG = CriterionErrorEnum.CriterionError.V(117)
        LISTING_GROUP_TREE_TOO_DEEP = CriterionErrorEnum.CriterionError.V(118)
        INVALID_LISTING_DIMENSION = CriterionErrorEnum.CriterionError.V(119)
        INVALID_LISTING_DIMENSION_TYPE = CriterionErrorEnum.CriterionError.V(120)
        ADVERTISER_NOT_ON_ALLOWLIST_FOR_COMBINED_AUDIENCE_ON_DISPLAY = (
            CriterionErrorEnum.CriterionError.V(127)
        )
        CANNOT_TARGET_REMOVED_COMBINED_AUDIENCE = CriterionErrorEnum.CriterionError.V(
            128
        )
        INVALID_COMBINED_AUDIENCE_ID = CriterionErrorEnum.CriterionError.V(129)
        CANNOT_TARGET_REMOVED_CUSTOM_AUDIENCE = CriterionErrorEnum.CriterionError.V(130)
    class CriterionError(metaclass=_CriterionError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = CriterionErrorEnum.CriterionError.V(0)
    UNKNOWN = CriterionErrorEnum.CriterionError.V(1)
    CONCRETE_TYPE_REQUIRED = CriterionErrorEnum.CriterionError.V(2)
    INVALID_EXCLUDED_CATEGORY = CriterionErrorEnum.CriterionError.V(3)
    INVALID_KEYWORD_TEXT = CriterionErrorEnum.CriterionError.V(4)
    KEYWORD_TEXT_TOO_LONG = CriterionErrorEnum.CriterionError.V(5)
    KEYWORD_HAS_TOO_MANY_WORDS = CriterionErrorEnum.CriterionError.V(6)
    KEYWORD_HAS_INVALID_CHARS = CriterionErrorEnum.CriterionError.V(7)
    INVALID_PLACEMENT_URL = CriterionErrorEnum.CriterionError.V(8)
    INVALID_USER_LIST = CriterionErrorEnum.CriterionError.V(9)
    INVALID_USER_INTEREST = CriterionErrorEnum.CriterionError.V(10)
    INVALID_FORMAT_FOR_PLACEMENT_URL = CriterionErrorEnum.CriterionError.V(11)
    PLACEMENT_URL_IS_TOO_LONG = CriterionErrorEnum.CriterionError.V(12)
    PLACEMENT_URL_HAS_ILLEGAL_CHAR = CriterionErrorEnum.CriterionError.V(13)
    PLACEMENT_URL_HAS_MULTIPLE_SITES_IN_LINE = CriterionErrorEnum.CriterionError.V(14)
    PLACEMENT_IS_NOT_AVAILABLE_FOR_TARGETING_OR_EXCLUSION = (
        CriterionErrorEnum.CriterionError.V(15)
    )
    INVALID_TOPIC_PATH = CriterionErrorEnum.CriterionError.V(16)
    INVALID_YOUTUBE_CHANNEL_ID = CriterionErrorEnum.CriterionError.V(17)
    INVALID_YOUTUBE_VIDEO_ID = CriterionErrorEnum.CriterionError.V(18)
    YOUTUBE_VERTICAL_CHANNEL_DEPRECATED = CriterionErrorEnum.CriterionError.V(19)
    YOUTUBE_DEMOGRAPHIC_CHANNEL_DEPRECATED = CriterionErrorEnum.CriterionError.V(20)
    YOUTUBE_URL_UNSUPPORTED = CriterionErrorEnum.CriterionError.V(21)
    CANNOT_EXCLUDE_CRITERIA_TYPE = CriterionErrorEnum.CriterionError.V(22)
    CANNOT_ADD_CRITERIA_TYPE = CriterionErrorEnum.CriterionError.V(23)
    CANNOT_EXCLUDE_SIMILAR_USER_LIST = CriterionErrorEnum.CriterionError.V(26)
    CANNOT_ADD_CLOSED_USER_LIST = CriterionErrorEnum.CriterionError.V(27)
    CANNOT_ADD_DISPLAY_ONLY_LISTS_TO_SEARCH_ONLY_CAMPAIGNS = (
        CriterionErrorEnum.CriterionError.V(28)
    )
    CANNOT_ADD_DISPLAY_ONLY_LISTS_TO_SEARCH_CAMPAIGNS = (
        CriterionErrorEnum.CriterionError.V(29)
    )
    CANNOT_ADD_DISPLAY_ONLY_LISTS_TO_SHOPPING_CAMPAIGNS = (
        CriterionErrorEnum.CriterionError.V(30)
    )
    CANNOT_ADD_USER_INTERESTS_TO_SEARCH_CAMPAIGNS = CriterionErrorEnum.CriterionError.V(
        31
    )
    CANNOT_SET_BIDS_ON_CRITERION_TYPE_IN_SEARCH_CAMPAIGNS = (
        CriterionErrorEnum.CriterionError.V(32)
    )
    CANNOT_ADD_URLS_TO_CRITERION_TYPE_FOR_CAMPAIGN_TYPE = (
        CriterionErrorEnum.CriterionError.V(33)
    )
    INVALID_COMBINED_AUDIENCE = CriterionErrorEnum.CriterionError.V(122)
    INVALID_CUSTOM_AFFINITY = CriterionErrorEnum.CriterionError.V(96)
    INVALID_CUSTOM_INTENT = CriterionErrorEnum.CriterionError.V(97)
    INVALID_CUSTOM_AUDIENCE = CriterionErrorEnum.CriterionError.V(121)
    INVALID_IP_ADDRESS = CriterionErrorEnum.CriterionError.V(34)
    INVALID_IP_FORMAT = CriterionErrorEnum.CriterionError.V(35)
    INVALID_MOBILE_APP = CriterionErrorEnum.CriterionError.V(36)
    INVALID_MOBILE_APP_CATEGORY = CriterionErrorEnum.CriterionError.V(37)
    INVALID_CRITERION_ID = CriterionErrorEnum.CriterionError.V(38)
    CANNOT_TARGET_CRITERION = CriterionErrorEnum.CriterionError.V(39)
    CANNOT_TARGET_OBSOLETE_CRITERION = CriterionErrorEnum.CriterionError.V(40)
    CRITERION_ID_AND_TYPE_MISMATCH = CriterionErrorEnum.CriterionError.V(41)
    INVALID_PROXIMITY_RADIUS = CriterionErrorEnum.CriterionError.V(42)
    INVALID_PROXIMITY_RADIUS_UNITS = CriterionErrorEnum.CriterionError.V(43)
    INVALID_STREETADDRESS_LENGTH = CriterionErrorEnum.CriterionError.V(44)
    INVALID_CITYNAME_LENGTH = CriterionErrorEnum.CriterionError.V(45)
    INVALID_REGIONCODE_LENGTH = CriterionErrorEnum.CriterionError.V(46)
    INVALID_REGIONNAME_LENGTH = CriterionErrorEnum.CriterionError.V(47)
    INVALID_POSTALCODE_LENGTH = CriterionErrorEnum.CriterionError.V(48)
    INVALID_COUNTRY_CODE = CriterionErrorEnum.CriterionError.V(49)
    INVALID_LATITUDE = CriterionErrorEnum.CriterionError.V(50)
    INVALID_LONGITUDE = CriterionErrorEnum.CriterionError.V(51)
    PROXIMITY_GEOPOINT_AND_ADDRESS_BOTH_CANNOT_BE_NULL = (
        CriterionErrorEnum.CriterionError.V(52)
    )
    INVALID_PROXIMITY_ADDRESS = CriterionErrorEnum.CriterionError.V(53)
    INVALID_USER_DOMAIN_NAME = CriterionErrorEnum.CriterionError.V(54)
    CRITERION_PARAMETER_TOO_LONG = CriterionErrorEnum.CriterionError.V(55)
    AD_SCHEDULE_TIME_INTERVALS_OVERLAP = CriterionErrorEnum.CriterionError.V(56)
    AD_SCHEDULE_INTERVAL_CANNOT_SPAN_MULTIPLE_DAYS = (
        CriterionErrorEnum.CriterionError.V(57)
    )
    AD_SCHEDULE_INVALID_TIME_INTERVAL = CriterionErrorEnum.CriterionError.V(58)
    AD_SCHEDULE_EXCEEDED_INTERVALS_PER_DAY_LIMIT = CriterionErrorEnum.CriterionError.V(
        59
    )
    AD_SCHEDULE_CRITERION_ID_MISMATCHING_FIELDS = CriterionErrorEnum.CriterionError.V(
        60
    )
    CANNOT_BID_MODIFY_CRITERION_TYPE = CriterionErrorEnum.CriterionError.V(61)
    CANNOT_BID_MODIFY_CRITERION_CAMPAIGN_OPTED_OUT = (
        CriterionErrorEnum.CriterionError.V(62)
    )
    CANNOT_BID_MODIFY_NEGATIVE_CRITERION = CriterionErrorEnum.CriterionError.V(63)
    BID_MODIFIER_ALREADY_EXISTS = CriterionErrorEnum.CriterionError.V(64)
    FEED_ID_NOT_ALLOWED = CriterionErrorEnum.CriterionError.V(65)
    ACCOUNT_INELIGIBLE_FOR_CRITERIA_TYPE = CriterionErrorEnum.CriterionError.V(66)
    CRITERIA_TYPE_INVALID_FOR_BIDDING_STRATEGY = CriterionErrorEnum.CriterionError.V(67)
    CANNOT_EXCLUDE_CRITERION = CriterionErrorEnum.CriterionError.V(68)
    CANNOT_REMOVE_CRITERION = CriterionErrorEnum.CriterionError.V(69)
    INVALID_PRODUCT_BIDDING_CATEGORY = CriterionErrorEnum.CriterionError.V(76)
    MISSING_SHOPPING_SETTING = CriterionErrorEnum.CriterionError.V(77)
    INVALID_MATCHING_FUNCTION = CriterionErrorEnum.CriterionError.V(78)
    LOCATION_FILTER_NOT_ALLOWED = CriterionErrorEnum.CriterionError.V(79)
    INVALID_FEED_FOR_LOCATION_FILTER = CriterionErrorEnum.CriterionError.V(98)
    LOCATION_FILTER_INVALID = CriterionErrorEnum.CriterionError.V(80)
    CANNOT_SET_GEO_TARGET_CONSTANTS_WITH_FEED_ITEM_SETS = (
        CriterionErrorEnum.CriterionError.V(123)
    )
    INVALID_LOCATION_GROUP_RADIUS = CriterionErrorEnum.CriterionError.V(124)
    INVALID_LOCATION_GROUP_RADIUS_UNIT = CriterionErrorEnum.CriterionError.V(125)
    CANNOT_ATTACH_CRITERIA_AT_CAMPAIGN_AND_ADGROUP = (
        CriterionErrorEnum.CriterionError.V(81)
    )
    HOTEL_LENGTH_OF_STAY_OVERLAPS_WITH_EXISTING_CRITERION = (
        CriterionErrorEnum.CriterionError.V(82)
    )
    HOTEL_ADVANCE_BOOKING_WINDOW_OVERLAPS_WITH_EXISTING_CRITERION = (
        CriterionErrorEnum.CriterionError.V(83)
    )
    FIELD_INCOMPATIBLE_WITH_NEGATIVE_TARGETING = CriterionErrorEnum.CriterionError.V(84)
    INVALID_WEBPAGE_CONDITION = CriterionErrorEnum.CriterionError.V(85)
    INVALID_WEBPAGE_CONDITION_URL = CriterionErrorEnum.CriterionError.V(86)
    WEBPAGE_CONDITION_URL_CANNOT_BE_EMPTY = CriterionErrorEnum.CriterionError.V(87)
    WEBPAGE_CONDITION_URL_UNSUPPORTED_PROTOCOL = CriterionErrorEnum.CriterionError.V(88)
    WEBPAGE_CONDITION_URL_CANNOT_BE_IP_ADDRESS = CriterionErrorEnum.CriterionError.V(89)
    WEBPAGE_CONDITION_URL_DOMAIN_NOT_CONSISTENT_WITH_CAMPAIGN_SETTING = (
        CriterionErrorEnum.CriterionError.V(90)
    )
    WEBPAGE_CONDITION_URL_CANNOT_BE_PUBLIC_SUFFIX = CriterionErrorEnum.CriterionError.V(
        91
    )
    WEBPAGE_CONDITION_URL_INVALID_PUBLIC_SUFFIX = CriterionErrorEnum.CriterionError.V(
        92
    )
    WEBPAGE_CONDITION_URL_VALUE_TRACK_VALUE_NOT_SUPPORTED = (
        CriterionErrorEnum.CriterionError.V(93)
    )
    WEBPAGE_CRITERION_URL_EQUALS_CAN_HAVE_ONLY_ONE_CONDITION = (
        CriterionErrorEnum.CriterionError.V(94)
    )
    WEBPAGE_CRITERION_NOT_SUPPORTED_ON_NON_DSA_AD_GROUP = (
        CriterionErrorEnum.CriterionError.V(95)
    )
    CANNOT_TARGET_USER_LIST_FOR_SMART_DISPLAY_CAMPAIGNS = (
        CriterionErrorEnum.CriterionError.V(99)
    )
    CANNOT_TARGET_PLACEMENTS_FOR_SEARCH_CAMPAIGNS = CriterionErrorEnum.CriterionError.V(
        126
    )
    LISTING_SCOPE_TOO_MANY_DIMENSION_TYPES = CriterionErrorEnum.CriterionError.V(100)
    LISTING_SCOPE_TOO_MANY_IN_OPERATORS = CriterionErrorEnum.CriterionError.V(101)
    LISTING_SCOPE_IN_OPERATOR_NOT_SUPPORTED = CriterionErrorEnum.CriterionError.V(102)
    DUPLICATE_LISTING_DIMENSION_TYPE = CriterionErrorEnum.CriterionError.V(103)
    DUPLICATE_LISTING_DIMENSION_VALUE = CriterionErrorEnum.CriterionError.V(104)
    CANNOT_SET_BIDS_ON_LISTING_GROUP_SUBDIVISION = CriterionErrorEnum.CriterionError.V(
        105
    )
    INVALID_LISTING_GROUP_HIERARCHY = CriterionErrorEnum.CriterionError.V(106)
    LISTING_GROUP_UNIT_CANNOT_HAVE_CHILDREN = CriterionErrorEnum.CriterionError.V(107)
    LISTING_GROUP_SUBDIVISION_REQUIRES_OTHERS_CASE = (
        CriterionErrorEnum.CriterionError.V(108)
    )
    LISTING_GROUP_REQUIRES_SAME_DIMENSION_TYPE_AS_SIBLINGS = (
        CriterionErrorEnum.CriterionError.V(109)
    )
    LISTING_GROUP_ALREADY_EXISTS = CriterionErrorEnum.CriterionError.V(110)
    LISTING_GROUP_DOES_NOT_EXIST = CriterionErrorEnum.CriterionError.V(111)
    LISTING_GROUP_CANNOT_BE_REMOVED = CriterionErrorEnum.CriterionError.V(112)
    INVALID_LISTING_GROUP_TYPE = CriterionErrorEnum.CriterionError.V(113)
    LISTING_GROUP_ADD_MAY_ONLY_USE_TEMP_ID = CriterionErrorEnum.CriterionError.V(114)
    LISTING_SCOPE_TOO_LONG = CriterionErrorEnum.CriterionError.V(115)
    LISTING_SCOPE_TOO_MANY_DIMENSIONS = CriterionErrorEnum.CriterionError.V(116)
    LISTING_GROUP_TOO_LONG = CriterionErrorEnum.CriterionError.V(117)
    LISTING_GROUP_TREE_TOO_DEEP = CriterionErrorEnum.CriterionError.V(118)
    INVALID_LISTING_DIMENSION = CriterionErrorEnum.CriterionError.V(119)
    INVALID_LISTING_DIMENSION_TYPE = CriterionErrorEnum.CriterionError.V(120)
    ADVERTISER_NOT_ON_ALLOWLIST_FOR_COMBINED_AUDIENCE_ON_DISPLAY = (
        CriterionErrorEnum.CriterionError.V(127)
    )
    CANNOT_TARGET_REMOVED_COMBINED_AUDIENCE = CriterionErrorEnum.CriterionError.V(128)
    INVALID_COMBINED_AUDIENCE_ID = CriterionErrorEnum.CriterionError.V(129)
    CANNOT_TARGET_REMOVED_CUSTOM_AUDIENCE = CriterionErrorEnum.CriterionError.V(130)
    def __init__(
        self,
    ) -> None: ...

global___CriterionErrorEnum = CriterionErrorEnum



from typing import (
    Any,
    Callable,
    ClassVar,
    Dict,
    Iterable,
    List,
    Optional,
    Sequence,
    Tuple,
    Union,
)

import grpc
from google.api_core.client_options import ClientOptions  # type: ignore
from google.api_core.gapic_v1.client_info import ClientInfo  # type: ignore
from google.api_core.retry import Retry  # type: ignore
from google.auth.credentials import Credentials  # type: ignore
from google.oauth2 import service_account as service_account  # type: ignore

from google.ads.google_ads.v5.proto.services import (
    reach_plan_service_pb2 as reach_plan_service_pb2,
)
from google.ads.google_ads.v5.services import (
    reach_plan_service_client_config as reach_plan_service_client_config,
)
from google.ads.google_ads.v5.services.transports import (
    reach_plan_service_grpc_transport as reach_plan_service_grpc_transport,
)
from google.ads.google_ads.v5.types import (
    CampaignDuration,
    FrequencyCap,
    GenerateProductMixIdeasResponse,
    GenerateReachForecastResponse,
    Int32Value,
    Int64Value,
    ListPlannableLocationsResponse,
    ListPlannableProductsResponse,
    PlannedProduct,
    Preferences,
    StringValue,
    Targeting,
)

class ReachPlanServiceClient:
    SERVICE_ADDRESS: ClassVar[str] = ...
    @classmethod
    def from_service_account_file(
        cls, filename: str, *args: Any, **kwargs: Any
    ) -> ReachPlanServiceClient: ...
    @classmethod
    def from_service_account_json(
        cls, filename: str, *args: Any, **kwargs: Any
    ) -> ReachPlanServiceClient: ...
    transport: Union[
        reach_plan_service_grpc_transport.ReachPlanServiceGrpcTransport,
        Callable[
            [Credentials, type],
            reach_plan_service_grpc_transport.ReachPlanServiceGrpcTransport,
        ],
    ] = ...
    def __init__(
        self,
        transport: Optional[
            Union[
                reach_plan_service_grpc_transport.ReachPlanServiceGrpcTransport,
                Callable[
                    [Credentials, type],
                    reach_plan_service_grpc_transport.ReachPlanServiceGrpcTransport,
                ],
            ]
        ] = ...,
        channel: Optional[grpc.Channel] = ...,
        credentials: Optional[Credentials] = ...,
        client_config: Optional[Dict[str, Any]] = ...,
        client_info: Optional[ClientInfo] = ...,
        client_options: Optional[Union[Dict[str, Any], ClientOptions]] = ...,
    ) -> None: ...
    def list_plannable_locations(
        self,
        retry: Optional[Retry] = ...,
        timeout: Optional[float] = ...,
        metadata: Optional[Sequence[Tuple[str, str]]] = ...,
    ) -> ListPlannableLocationsResponse: ...
    def list_plannable_products(
        self,
        plannable_location_id: Union[Dict[str, Any], StringValue],
        retry: Optional[Retry] = ...,
        timeout: Optional[float] = ...,
        metadata: Optional[Sequence[Tuple[str, str]]] = ...,
    ) -> ListPlannableProductsResponse: ...
    def generate_product_mix_ideas(
        self,
        customer_id: str,
        plannable_location_id: Union[Dict[str, Any], StringValue],
        currency_code: Union[Dict[str, Any], StringValue],
        budget_micros: Union[Dict[str, Any], Int64Value],
        preferences: Optional[Union[Dict[str, Any], Preferences]] = ...,
        retry: Optional[Retry] = ...,
        timeout: Optional[float] = ...,
        metadata: Optional[Sequence[Tuple[str, str]]] = ...,
    ) -> GenerateProductMixIdeasResponse: ...
    def generate_reach_forecast(
        self,
        customer_id: str,
        campaign_duration: Union[Dict[str, Any], CampaignDuration],
        planned_products: List[Union[Dict[str, Any], PlannedProduct]],
        currency_code: Optional[Union[Dict[str, Any], StringValue]] = ...,
        cookie_frequency_cap: Optional[Union[Dict[str, Any], Int32Value]] = ...,
        cookie_frequency_cap_setting: Optional[
            Union[Dict[str, Any], FrequencyCap]
        ] = ...,
        min_effective_frequency: Optional[Union[Dict[str, Any], Int32Value]] = ...,
        targeting: Optional[Union[Dict[str, Any], Targeting]] = ...,
        retry: Optional[Retry] = ...,
        timeout: Optional[float] = ...,
        metadata: Optional[Sequence[Tuple[str, str]]] = ...,
    ) -> GenerateReachForecastResponse: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v6.proto.resources.feed_item_set_link_pb2
import grpc

from .feed_item_set_link_service_pb2 import *

class FeedItemSetLinkServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetFeedItemSetLink(
        self,
        request: global___GetFeedItemSetLinkRequest,
    ) -> google.ads.google_ads.v6.proto.resources.feed_item_set_link_pb2.FeedItemSetLink: ...
    def MutateFeedItemSetLinks(
        self,
        request: global___MutateFeedItemSetLinksRequest,
    ) -> global___MutateFeedItemSetLinksResponse: ...

class FeedItemSetLinkServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetFeedItemSetLink(
        self,
        request: global___GetFeedItemSetLinkRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v6.proto.resources.feed_item_set_link_pb2.FeedItemSetLink: ...
    @abc.abstractmethod
    def MutateFeedItemSetLinks(
        self,
        request: global___MutateFeedItemSetLinksRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateFeedItemSetLinksResponse: ...

def add_FeedItemSetLinkServiceServicer_to_server(
    servicer: FeedItemSetLinkServiceServicer, server: grpc.Server
) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class MobileAppVendorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _MobileAppVendor(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[MobileAppVendor.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = MobileAppVendorEnum.MobileAppVendor.V(0)
        UNKNOWN = MobileAppVendorEnum.MobileAppVendor.V(1)
        APPLE_APP_STORE = MobileAppVendorEnum.MobileAppVendor.V(2)
        GOOGLE_APP_STORE = MobileAppVendorEnum.MobileAppVendor.V(3)
    class MobileAppVendor(metaclass=_MobileAppVendor):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = MobileAppVendorEnum.MobileAppVendor.V(0)
    UNKNOWN = MobileAppVendorEnum.MobileAppVendor.V(1)
    APPLE_APP_STORE = MobileAppVendorEnum.MobileAppVendor.V(2)
    GOOGLE_APP_STORE = MobileAppVendorEnum.MobileAppVendor.V(3)
    def __init__(
        self,
    ) -> None: ...

global___MobileAppVendorEnum = MobileAppVendorEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class PolicyApprovalStatusEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _PolicyApprovalStatus(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            PolicyApprovalStatus.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = PolicyApprovalStatusEnum.PolicyApprovalStatus.V(0)
        UNKNOWN = PolicyApprovalStatusEnum.PolicyApprovalStatus.V(1)
        DISAPPROVED = PolicyApprovalStatusEnum.PolicyApprovalStatus.V(2)
        APPROVED_LIMITED = PolicyApprovalStatusEnum.PolicyApprovalStatus.V(3)
        APPROVED = PolicyApprovalStatusEnum.PolicyApprovalStatus.V(4)
        AREA_OF_INTEREST_ONLY = PolicyApprovalStatusEnum.PolicyApprovalStatus.V(5)
    class PolicyApprovalStatus(metaclass=_PolicyApprovalStatus):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = PolicyApprovalStatusEnum.PolicyApprovalStatus.V(0)
    UNKNOWN = PolicyApprovalStatusEnum.PolicyApprovalStatus.V(1)
    DISAPPROVED = PolicyApprovalStatusEnum.PolicyApprovalStatus.V(2)
    APPROVED_LIMITED = PolicyApprovalStatusEnum.PolicyApprovalStatus.V(3)
    APPROVED = PolicyApprovalStatusEnum.PolicyApprovalStatus.V(4)
    AREA_OF_INTEREST_ONLY = PolicyApprovalStatusEnum.PolicyApprovalStatus.V(5)
    def __init__(
        self,
    ) -> None: ...

global___PolicyApprovalStatusEnum = PolicyApprovalStatusEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ExtensionTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _ExtensionType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ExtensionType.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = ExtensionTypeEnum.ExtensionType.V(0)
        UNKNOWN = ExtensionTypeEnum.ExtensionType.V(1)
        NONE = ExtensionTypeEnum.ExtensionType.V(2)
        APP = ExtensionTypeEnum.ExtensionType.V(3)
        CALL = ExtensionTypeEnum.ExtensionType.V(4)
        CALLOUT = ExtensionTypeEnum.ExtensionType.V(5)
        MESSAGE = ExtensionTypeEnum.ExtensionType.V(6)
        PRICE = ExtensionTypeEnum.ExtensionType.V(7)
        PROMOTION = ExtensionTypeEnum.ExtensionType.V(8)
        SITELINK = ExtensionTypeEnum.ExtensionType.V(10)
        STRUCTURED_SNIPPET = ExtensionTypeEnum.ExtensionType.V(11)
        LOCATION = ExtensionTypeEnum.ExtensionType.V(12)
        AFFILIATE_LOCATION = ExtensionTypeEnum.ExtensionType.V(13)
        HOTEL_CALLOUT = ExtensionTypeEnum.ExtensionType.V(15)
    class ExtensionType(metaclass=_ExtensionType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = ExtensionTypeEnum.ExtensionType.V(0)
    UNKNOWN = ExtensionTypeEnum.ExtensionType.V(1)
    NONE = ExtensionTypeEnum.ExtensionType.V(2)
    APP = ExtensionTypeEnum.ExtensionType.V(3)
    CALL = ExtensionTypeEnum.ExtensionType.V(4)
    CALLOUT = ExtensionTypeEnum.ExtensionType.V(5)
    MESSAGE = ExtensionTypeEnum.ExtensionType.V(6)
    PRICE = ExtensionTypeEnum.ExtensionType.V(7)
    PROMOTION = ExtensionTypeEnum.ExtensionType.V(8)
    SITELINK = ExtensionTypeEnum.ExtensionType.V(10)
    STRUCTURED_SNIPPET = ExtensionTypeEnum.ExtensionType.V(11)
    LOCATION = ExtensionTypeEnum.ExtensionType.V(12)
    AFFILIATE_LOCATION = ExtensionTypeEnum.ExtensionType.V(13)
    HOTEL_CALLOUT = ExtensionTypeEnum.ExtensionType.V(15)
    def __init__(
        self,
    ) -> None: ...

global___ExtensionTypeEnum = ExtensionTypeEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v5.proto.enums.campaign_draft_status_pb2
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CampaignDraft(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    DRAFT_ID_FIELD_NUMBER: builtins.int
    BASE_CAMPAIGN_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DRAFT_CAMPAIGN_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    HAS_EXPERIMENT_RUNNING_FIELD_NUMBER: builtins.int
    LONG_RUNNING_OPERATION_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    status: google.ads.google_ads.v5.proto.enums.campaign_draft_status_pb2.CampaignDraftStatusEnum.CampaignDraftStatus.V = (
        ...
    )
    @property
    def draft_id(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def base_campaign(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def name(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def draft_campaign(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def has_experiment_running(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def long_running_operation(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        draft_id: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        base_campaign: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        name: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        draft_campaign: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        status: google.ads.google_ads.v5.proto.enums.campaign_draft_status_pb2.CampaignDraftStatusEnum.CampaignDraftStatus.V = ...,
        has_experiment_running: typing.Optional[
            google.protobuf.wrappers_pb2.BoolValue
        ] = ...,
        long_running_operation: typing.Optional[
            google.protobuf.wrappers_pb2.StringValue
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "base_campaign",
            b"base_campaign",
            "draft_campaign",
            b"draft_campaign",
            "draft_id",
            b"draft_id",
            "has_experiment_running",
            b"has_experiment_running",
            "long_running_operation",
            b"long_running_operation",
            "name",
            b"name",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "base_campaign",
            b"base_campaign",
            "draft_campaign",
            b"draft_campaign",
            "draft_id",
            b"draft_id",
            "has_experiment_running",
            b"has_experiment_running",
            "long_running_operation",
            b"long_running_operation",
            "name",
            b"name",
            "resource_name",
            b"resource_name",
            "status",
            b"status",
        ],
    ) -> None: ...

global___CampaignDraft = CampaignDraft



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class FeedItemTargetErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _FeedItemTargetError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            FeedItemTargetError.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = FeedItemTargetErrorEnum.FeedItemTargetError.V(0)
        UNKNOWN = FeedItemTargetErrorEnum.FeedItemTargetError.V(1)
        MUST_SET_TARGET_ONEOF_ON_CREATE = FeedItemTargetErrorEnum.FeedItemTargetError.V(
            2
        )
        FEED_ITEM_TARGET_ALREADY_EXISTS = FeedItemTargetErrorEnum.FeedItemTargetError.V(
            3
        )
        FEED_ITEM_SCHEDULES_CANNOT_OVERLAP = (
            FeedItemTargetErrorEnum.FeedItemTargetError.V(4)
        )
        TARGET_LIMIT_EXCEEDED_FOR_GIVEN_TYPE = (
            FeedItemTargetErrorEnum.FeedItemTargetError.V(5)
        )
        TOO_MANY_SCHEDULES_PER_DAY = FeedItemTargetErrorEnum.FeedItemTargetError.V(6)
        CANNOT_HAVE_ENABLED_CAMPAIGN_AND_ENABLED_AD_GROUP_TARGETS = (
            FeedItemTargetErrorEnum.FeedItemTargetError.V(7)
        )
        DUPLICATE_AD_SCHEDULE = FeedItemTargetErrorEnum.FeedItemTargetError.V(8)
        DUPLICATE_KEYWORD = FeedItemTargetErrorEnum.FeedItemTargetError.V(9)
    class FeedItemTargetError(metaclass=_FeedItemTargetError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = FeedItemTargetErrorEnum.FeedItemTargetError.V(0)
    UNKNOWN = FeedItemTargetErrorEnum.FeedItemTargetError.V(1)
    MUST_SET_TARGET_ONEOF_ON_CREATE = FeedItemTargetErrorEnum.FeedItemTargetError.V(2)
    FEED_ITEM_TARGET_ALREADY_EXISTS = FeedItemTargetErrorEnum.FeedItemTargetError.V(3)
    FEED_ITEM_SCHEDULES_CANNOT_OVERLAP = FeedItemTargetErrorEnum.FeedItemTargetError.V(
        4
    )
    TARGET_LIMIT_EXCEEDED_FOR_GIVEN_TYPE = (
        FeedItemTargetErrorEnum.FeedItemTargetError.V(5)
    )
    TOO_MANY_SCHEDULES_PER_DAY = FeedItemTargetErrorEnum.FeedItemTargetError.V(6)
    CANNOT_HAVE_ENABLED_CAMPAIGN_AND_ENABLED_AD_GROUP_TARGETS = (
        FeedItemTargetErrorEnum.FeedItemTargetError.V(7)
    )
    DUPLICATE_AD_SCHEDULE = FeedItemTargetErrorEnum.FeedItemTargetError.V(8)
    DUPLICATE_KEYWORD = FeedItemTargetErrorEnum.FeedItemTargetError.V(9)
    def __init__(
        self,
    ) -> None: ...

global___FeedItemTargetErrorEnum = FeedItemTargetErrorEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v5.proto.resources.campaign_draft_pb2
import google.longrunning.operations_pb2
import grpc

from .campaign_draft_service_pb2 import *

class CampaignDraftServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetCampaignDraft(
        self,
        request: global___GetCampaignDraftRequest,
    ) -> google.ads.google_ads.v5.proto.resources.campaign_draft_pb2.CampaignDraft: ...
    def MutateCampaignDrafts(
        self,
        request: global___MutateCampaignDraftsRequest,
    ) -> global___MutateCampaignDraftsResponse: ...
    def PromoteCampaignDraft(
        self,
        request: global___PromoteCampaignDraftRequest,
    ) -> google.longrunning.operations_pb2.Operation: ...
    def ListCampaignDraftAsyncErrors(
        self,
        request: global___ListCampaignDraftAsyncErrorsRequest,
    ) -> global___ListCampaignDraftAsyncErrorsResponse: ...

class CampaignDraftServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetCampaignDraft(
        self,
        request: global___GetCampaignDraftRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v5.proto.resources.campaign_draft_pb2.CampaignDraft: ...
    @abc.abstractmethod
    def MutateCampaignDrafts(
        self,
        request: global___MutateCampaignDraftsRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateCampaignDraftsResponse: ...
    @abc.abstractmethod
    def PromoteCampaignDraft(
        self,
        request: global___PromoteCampaignDraftRequest,
        context: grpc.ServicerContext,
    ) -> google.longrunning.operations_pb2.Operation: ...
    @abc.abstractmethod
    def ListCampaignDraftAsyncErrors(
        self,
        request: global___ListCampaignDraftAsyncErrorsRequest,
        context: grpc.ServicerContext,
    ) -> global___ListCampaignDraftAsyncErrorsResponse: ...

def add_CampaignDraftServiceServicer_to_server(
    servicer: CampaignDraftServiceServicer, server: grpc.Server
) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v4.proto.enums.campaign_experiment_status_pb2
import google.ads.google_ads.v4.proto.enums.campaign_experiment_traffic_split_type_pb2
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CampaignExperiment(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    CAMPAIGN_DRAFT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    TRAFFIC_SPLIT_PERCENT_FIELD_NUMBER: builtins.int
    TRAFFIC_SPLIT_TYPE_FIELD_NUMBER: builtins.int
    EXPERIMENT_CAMPAIGN_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    LONG_RUNNING_OPERATION_FIELD_NUMBER: builtins.int
    START_DATE_FIELD_NUMBER: builtins.int
    END_DATE_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    traffic_split_type: google.ads.google_ads.v4.proto.enums.campaign_experiment_traffic_split_type_pb2.CampaignExperimentTrafficSplitTypeEnum.CampaignExperimentTrafficSplitType.V = (
        ...
    )
    status: google.ads.google_ads.v4.proto.enums.campaign_experiment_status_pb2.CampaignExperimentStatusEnum.CampaignExperimentStatus.V = (
        ...
    )
    @property
    def id(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def campaign_draft(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def name(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def description(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def traffic_split_percent(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def experiment_campaign(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def long_running_operation(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def start_date(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def end_date(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        id: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        campaign_draft: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        name: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        description: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        traffic_split_percent: typing.Optional[
            google.protobuf.wrappers_pb2.Int64Value
        ] = ...,
        traffic_split_type: google.ads.google_ads.v4.proto.enums.campaign_experiment_traffic_split_type_pb2.CampaignExperimentTrafficSplitTypeEnum.CampaignExperimentTrafficSplitType.V = ...,
        experiment_campaign: typing.Optional[
            google.protobuf.wrappers_pb2.StringValue
        ] = ...,
        status: google.ads.google_ads.v4.proto.enums.campaign_experiment_status_pb2.CampaignExperimentStatusEnum.CampaignExperimentStatus.V = ...,
        long_running_operation: typing.Optional[
            google.protobuf.wrappers_pb2.StringValue
        ] = ...,
        start_date: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        end_date: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "campaign_draft",
            b"campaign_draft",
            "description",
            b"description",
            "end_date",
            b"end_date",
            "experiment_campaign",
            b"experiment_campaign",
            "id",
            b"id",
            "long_running_operation",
            b"long_running_operation",
            "name",
            b"name",
            "start_date",
            b"start_date",
            "traffic_split_percent",
            b"traffic_split_percent",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "campaign_draft",
            b"campaign_draft",
            "description",
            b"description",
            "end_date",
            b"end_date",
            "experiment_campaign",
            b"experiment_campaign",
            "id",
            b"id",
            "long_running_operation",
            b"long_running_operation",
            "name",
            b"name",
            "resource_name",
            b"resource_name",
            "start_date",
            b"start_date",
            "status",
            b"status",
            "traffic_split_percent",
            b"traffic_split_percent",
            "traffic_split_type",
            b"traffic_split_type",
        ],
    ) -> None: ...

global___CampaignExperiment = CampaignExperiment



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class AssetTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _AssetType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[AssetType.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = AssetTypeEnum.AssetType.V(0)
        UNKNOWN = AssetTypeEnum.AssetType.V(1)
        YOUTUBE_VIDEO = AssetTypeEnum.AssetType.V(2)
        MEDIA_BUNDLE = AssetTypeEnum.AssetType.V(3)
        IMAGE = AssetTypeEnum.AssetType.V(4)
        TEXT = AssetTypeEnum.AssetType.V(5)
        LEAD_FORM = AssetTypeEnum.AssetType.V(6)
        BOOK_ON_GOOGLE = AssetTypeEnum.AssetType.V(7)
    class AssetType(metaclass=_AssetType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = AssetTypeEnum.AssetType.V(0)
    UNKNOWN = AssetTypeEnum.AssetType.V(1)
    YOUTUBE_VIDEO = AssetTypeEnum.AssetType.V(2)
    MEDIA_BUNDLE = AssetTypeEnum.AssetType.V(3)
    IMAGE = AssetTypeEnum.AssetType.V(4)
    TEXT = AssetTypeEnum.AssetType.V(5)
    LEAD_FORM = AssetTypeEnum.AssetType.V(6)
    BOOK_ON_GOOGLE = AssetTypeEnum.AssetType.V(7)
    def __init__(
        self,
    ) -> None: ...

global___AssetTypeEnum = AssetTypeEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class AdGroupAdStatusEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _AdGroupAdStatus(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[AdGroupAdStatus.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = AdGroupAdStatusEnum.AdGroupAdStatus.V(0)
        UNKNOWN = AdGroupAdStatusEnum.AdGroupAdStatus.V(1)
        ENABLED = AdGroupAdStatusEnum.AdGroupAdStatus.V(2)
        PAUSED = AdGroupAdStatusEnum.AdGroupAdStatus.V(3)
        REMOVED = AdGroupAdStatusEnum.AdGroupAdStatus.V(4)
    class AdGroupAdStatus(metaclass=_AdGroupAdStatus):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = AdGroupAdStatusEnum.AdGroupAdStatus.V(0)
    UNKNOWN = AdGroupAdStatusEnum.AdGroupAdStatus.V(1)
    ENABLED = AdGroupAdStatusEnum.AdGroupAdStatus.V(2)
    PAUSED = AdGroupAdStatusEnum.AdGroupAdStatus.V(3)
    REMOVED = AdGroupAdStatusEnum.AdGroupAdStatus.V(4)
    def __init__(
        self,
    ) -> None: ...

global___AdGroupAdStatusEnum = AdGroupAdStatusEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v6.proto.enums.merchant_center_link_status_pb2
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class MerchantCenterLink(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MERCHANT_CENTER_ACCOUNT_NAME_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    id: builtins.int = ...
    merchant_center_account_name: typing.Text = ...
    status: google.ads.google_ads.v6.proto.enums.merchant_center_link_status_pb2.MerchantCenterLinkStatusEnum.MerchantCenterLinkStatus.V = (
        ...
    )
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        id: builtins.int = ...,
        merchant_center_account_name: typing.Text = ...,
        status: google.ads.google_ads.v6.proto.enums.merchant_center_link_status_pb2.MerchantCenterLinkStatusEnum.MerchantCenterLinkStatus.V = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_id",
            b"_id",
            "_merchant_center_account_name",
            b"_merchant_center_account_name",
            "id",
            b"id",
            "merchant_center_account_name",
            b"merchant_center_account_name",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_id",
            b"_id",
            "_merchant_center_account_name",
            b"_merchant_center_account_name",
            "id",
            b"id",
            "merchant_center_account_name",
            b"merchant_center_account_name",
            "resource_name",
            b"resource_name",
            "status",
            b"status",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_id", b"_id"]
    ) -> typing_extensions.Literal["id"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_merchant_center_account_name", b"_merchant_center_account_name"
        ],
    ) -> typing_extensions.Literal["merchant_center_account_name"]: ...

global___MerchantCenterLink = MerchantCenterLink



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CustomerClient(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    CLIENT_CUSTOMER_FIELD_NUMBER: builtins.int
    HIDDEN_FIELD_NUMBER: builtins.int
    LEVEL_FIELD_NUMBER: builtins.int
    TIME_ZONE_FIELD_NUMBER: builtins.int
    TEST_ACCOUNT_FIELD_NUMBER: builtins.int
    MANAGER_FIELD_NUMBER: builtins.int
    DESCRIPTIVE_NAME_FIELD_NUMBER: builtins.int
    CURRENCY_CODE_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    client_customer: typing.Text = ...
    hidden: builtins.bool = ...
    level: builtins.int = ...
    time_zone: typing.Text = ...
    test_account: builtins.bool = ...
    manager: builtins.bool = ...
    descriptive_name: typing.Text = ...
    currency_code: typing.Text = ...
    id: builtins.int = ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        client_customer: typing.Text = ...,
        hidden: builtins.bool = ...,
        level: builtins.int = ...,
        time_zone: typing.Text = ...,
        test_account: builtins.bool = ...,
        manager: builtins.bool = ...,
        descriptive_name: typing.Text = ...,
        currency_code: typing.Text = ...,
        id: builtins.int = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_client_customer",
            b"_client_customer",
            "_currency_code",
            b"_currency_code",
            "_descriptive_name",
            b"_descriptive_name",
            "_hidden",
            b"_hidden",
            "_id",
            b"_id",
            "_level",
            b"_level",
            "_manager",
            b"_manager",
            "_test_account",
            b"_test_account",
            "_time_zone",
            b"_time_zone",
            "client_customer",
            b"client_customer",
            "currency_code",
            b"currency_code",
            "descriptive_name",
            b"descriptive_name",
            "hidden",
            b"hidden",
            "id",
            b"id",
            "level",
            b"level",
            "manager",
            b"manager",
            "test_account",
            b"test_account",
            "time_zone",
            b"time_zone",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_client_customer",
            b"_client_customer",
            "_currency_code",
            b"_currency_code",
            "_descriptive_name",
            b"_descriptive_name",
            "_hidden",
            b"_hidden",
            "_id",
            b"_id",
            "_level",
            b"_level",
            "_manager",
            b"_manager",
            "_test_account",
            b"_test_account",
            "_time_zone",
            b"_time_zone",
            "client_customer",
            b"client_customer",
            "currency_code",
            b"currency_code",
            "descriptive_name",
            b"descriptive_name",
            "hidden",
            b"hidden",
            "id",
            b"id",
            "level",
            b"level",
            "manager",
            b"manager",
            "resource_name",
            b"resource_name",
            "test_account",
            b"test_account",
            "time_zone",
            b"time_zone",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_client_customer", b"_client_customer"],
    ) -> typing_extensions.Literal["client_customer"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_currency_code", b"_currency_code"],
    ) -> typing_extensions.Literal["currency_code"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_descriptive_name", b"_descriptive_name"
        ],
    ) -> typing_extensions.Literal["descriptive_name"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_hidden", b"_hidden"]
    ) -> typing_extensions.Literal["hidden"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_id", b"_id"]
    ) -> typing_extensions.Literal["id"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_level", b"_level"]
    ) -> typing_extensions.Literal["level"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_manager", b"_manager"]
    ) -> typing_extensions.Literal["manager"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_test_account", b"_test_account"]
    ) -> typing_extensions.Literal["test_account"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_time_zone", b"_time_zone"]
    ) -> typing_extensions.Literal["time_zone"]: ...

global___CustomerClient = CustomerClient



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class PaymentModeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _PaymentMode(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PaymentMode.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = PaymentModeEnum.PaymentMode.V(0)
        UNKNOWN = PaymentModeEnum.PaymentMode.V(1)
        CLICKS = PaymentModeEnum.PaymentMode.V(4)
        CONVERSION_VALUE = PaymentModeEnum.PaymentMode.V(5)
        CONVERSIONS = PaymentModeEnum.PaymentMode.V(6)
        GUEST_STAY = PaymentModeEnum.PaymentMode.V(7)
    class PaymentMode(metaclass=_PaymentMode):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = PaymentModeEnum.PaymentMode.V(0)
    UNKNOWN = PaymentModeEnum.PaymentMode.V(1)
    CLICKS = PaymentModeEnum.PaymentMode.V(4)
    CONVERSION_VALUE = PaymentModeEnum.PaymentMode.V(5)
    CONVERSIONS = PaymentModeEnum.PaymentMode.V(6)
    GUEST_STAY = PaymentModeEnum.PaymentMode.V(7)
    def __init__(
        self,
    ) -> None: ...

global___PaymentModeEnum = PaymentModeEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CustomAudienceMemberTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _CustomAudienceMemberType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            CustomAudienceMemberType.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = CustomAudienceMemberTypeEnum.CustomAudienceMemberType.V(0)
        UNKNOWN = CustomAudienceMemberTypeEnum.CustomAudienceMemberType.V(1)
        KEYWORD = CustomAudienceMemberTypeEnum.CustomAudienceMemberType.V(2)
        URL = CustomAudienceMemberTypeEnum.CustomAudienceMemberType.V(3)
        PLACE_CATEGORY = CustomAudienceMemberTypeEnum.CustomAudienceMemberType.V(4)
        APP = CustomAudienceMemberTypeEnum.CustomAudienceMemberType.V(5)
    class CustomAudienceMemberType(metaclass=_CustomAudienceMemberType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = CustomAudienceMemberTypeEnum.CustomAudienceMemberType.V(0)
    UNKNOWN = CustomAudienceMemberTypeEnum.CustomAudienceMemberType.V(1)
    KEYWORD = CustomAudienceMemberTypeEnum.CustomAudienceMemberType.V(2)
    URL = CustomAudienceMemberTypeEnum.CustomAudienceMemberType.V(3)
    PLACE_CATEGORY = CustomAudienceMemberTypeEnum.CustomAudienceMemberType.V(4)
    APP = CustomAudienceMemberTypeEnum.CustomAudienceMemberType.V(5)
    def __init__(
        self,
    ) -> None: ...

global___CustomAudienceMemberTypeEnum = CustomAudienceMemberTypeEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class BiddingStrategyTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _BiddingStrategyType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            BiddingStrategyType.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = BiddingStrategyTypeEnum.BiddingStrategyType.V(0)
        UNKNOWN = BiddingStrategyTypeEnum.BiddingStrategyType.V(1)
        COMMISSION = BiddingStrategyTypeEnum.BiddingStrategyType.V(16)
        ENHANCED_CPC = BiddingStrategyTypeEnum.BiddingStrategyType.V(2)
        MANUAL_CPC = BiddingStrategyTypeEnum.BiddingStrategyType.V(3)
        MANUAL_CPM = BiddingStrategyTypeEnum.BiddingStrategyType.V(4)
        MANUAL_CPV = BiddingStrategyTypeEnum.BiddingStrategyType.V(13)
        MAXIMIZE_CONVERSIONS = BiddingStrategyTypeEnum.BiddingStrategyType.V(10)
        MAXIMIZE_CONVERSION_VALUE = BiddingStrategyTypeEnum.BiddingStrategyType.V(11)
        PAGE_ONE_PROMOTED = BiddingStrategyTypeEnum.BiddingStrategyType.V(5)
        PERCENT_CPC = BiddingStrategyTypeEnum.BiddingStrategyType.V(12)
        TARGET_CPA = BiddingStrategyTypeEnum.BiddingStrategyType.V(6)
        TARGET_CPM = BiddingStrategyTypeEnum.BiddingStrategyType.V(14)
        TARGET_IMPRESSION_SHARE = BiddingStrategyTypeEnum.BiddingStrategyType.V(15)
        TARGET_OUTRANK_SHARE = BiddingStrategyTypeEnum.BiddingStrategyType.V(7)
        TARGET_ROAS = BiddingStrategyTypeEnum.BiddingStrategyType.V(8)
        TARGET_SPEND = BiddingStrategyTypeEnum.BiddingStrategyType.V(9)
    class BiddingStrategyType(metaclass=_BiddingStrategyType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = BiddingStrategyTypeEnum.BiddingStrategyType.V(0)
    UNKNOWN = BiddingStrategyTypeEnum.BiddingStrategyType.V(1)
    COMMISSION = BiddingStrategyTypeEnum.BiddingStrategyType.V(16)
    ENHANCED_CPC = BiddingStrategyTypeEnum.BiddingStrategyType.V(2)
    MANUAL_CPC = BiddingStrategyTypeEnum.BiddingStrategyType.V(3)
    MANUAL_CPM = BiddingStrategyTypeEnum.BiddingStrategyType.V(4)
    MANUAL_CPV = BiddingStrategyTypeEnum.BiddingStrategyType.V(13)
    MAXIMIZE_CONVERSIONS = BiddingStrategyTypeEnum.BiddingStrategyType.V(10)
    MAXIMIZE_CONVERSION_VALUE = BiddingStrategyTypeEnum.BiddingStrategyType.V(11)
    PAGE_ONE_PROMOTED = BiddingStrategyTypeEnum.BiddingStrategyType.V(5)
    PERCENT_CPC = BiddingStrategyTypeEnum.BiddingStrategyType.V(12)
    TARGET_CPA = BiddingStrategyTypeEnum.BiddingStrategyType.V(6)
    TARGET_CPM = BiddingStrategyTypeEnum.BiddingStrategyType.V(14)
    TARGET_IMPRESSION_SHARE = BiddingStrategyTypeEnum.BiddingStrategyType.V(15)
    TARGET_OUTRANK_SHARE = BiddingStrategyTypeEnum.BiddingStrategyType.V(7)
    TARGET_ROAS = BiddingStrategyTypeEnum.BiddingStrategyType.V(8)
    TARGET_SPEND = BiddingStrategyTypeEnum.BiddingStrategyType.V(9)
    def __init__(
        self,
    ) -> None: ...

global___BiddingStrategyTypeEnum = BiddingStrategyTypeEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CallConversionReportingStateEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _CallConversionReportingState(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            CallConversionReportingState.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = CallConversionReportingStateEnum.CallConversionReportingState.V(0)
        UNKNOWN = CallConversionReportingStateEnum.CallConversionReportingState.V(1)
        DISABLED = CallConversionReportingStateEnum.CallConversionReportingState.V(2)
        USE_ACCOUNT_LEVEL_CALL_CONVERSION_ACTION = (
            CallConversionReportingStateEnum.CallConversionReportingState.V(3)
        )
        USE_RESOURCE_LEVEL_CALL_CONVERSION_ACTION = (
            CallConversionReportingStateEnum.CallConversionReportingState.V(4)
        )
    class CallConversionReportingState(metaclass=_CallConversionReportingState):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = CallConversionReportingStateEnum.CallConversionReportingState.V(0)
    UNKNOWN = CallConversionReportingStateEnum.CallConversionReportingState.V(1)
    DISABLED = CallConversionReportingStateEnum.CallConversionReportingState.V(2)
    USE_ACCOUNT_LEVEL_CALL_CONVERSION_ACTION = (
        CallConversionReportingStateEnum.CallConversionReportingState.V(3)
    )
    USE_RESOURCE_LEVEL_CALL_CONVERSION_ACTION = (
        CallConversionReportingStateEnum.CallConversionReportingState.V(4)
    )
    def __init__(
        self,
    ) -> None: ...

global___CallConversionReportingStateEnum = CallConversionReportingStateEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v5.proto.resources.google_ads_field_pb2
import grpc

from .google_ads_field_service_pb2 import *

class GoogleAdsFieldServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetGoogleAdsField(
        self,
        request: global___GetGoogleAdsFieldRequest,
    ) -> google.ads.google_ads.v5.proto.resources.google_ads_field_pb2.GoogleAdsField: ...
    def SearchGoogleAdsFields(
        self,
        request: global___SearchGoogleAdsFieldsRequest,
    ) -> global___SearchGoogleAdsFieldsResponse: ...

class GoogleAdsFieldServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetGoogleAdsField(
        self,
        request: global___GetGoogleAdsFieldRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v5.proto.resources.google_ads_field_pb2.GoogleAdsField: ...
    @abc.abstractmethod
    def SearchGoogleAdsFields(
        self,
        request: global___SearchGoogleAdsFieldsRequest,
        context: grpc.ServicerContext,
    ) -> global___SearchGoogleAdsFieldsResponse: ...

def add_GoogleAdsFieldServiceServicer_to_server(
    servicer: GoogleAdsFieldServiceServicer, server: grpc.Server
) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class AgeRangeTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _AgeRangeType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[AgeRangeType.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = AgeRangeTypeEnum.AgeRangeType.V(0)
        UNKNOWN = AgeRangeTypeEnum.AgeRangeType.V(1)
        AGE_RANGE_18_24 = AgeRangeTypeEnum.AgeRangeType.V(503001)
        AGE_RANGE_25_34 = AgeRangeTypeEnum.AgeRangeType.V(503002)
        AGE_RANGE_35_44 = AgeRangeTypeEnum.AgeRangeType.V(503003)
        AGE_RANGE_45_54 = AgeRangeTypeEnum.AgeRangeType.V(503004)
        AGE_RANGE_55_64 = AgeRangeTypeEnum.AgeRangeType.V(503005)
        AGE_RANGE_65_UP = AgeRangeTypeEnum.AgeRangeType.V(503006)
        AGE_RANGE_UNDETERMINED = AgeRangeTypeEnum.AgeRangeType.V(503999)
    class AgeRangeType(metaclass=_AgeRangeType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = AgeRangeTypeEnum.AgeRangeType.V(0)
    UNKNOWN = AgeRangeTypeEnum.AgeRangeType.V(1)
    AGE_RANGE_18_24 = AgeRangeTypeEnum.AgeRangeType.V(503001)
    AGE_RANGE_25_34 = AgeRangeTypeEnum.AgeRangeType.V(503002)
    AGE_RANGE_35_44 = AgeRangeTypeEnum.AgeRangeType.V(503003)
    AGE_RANGE_45_54 = AgeRangeTypeEnum.AgeRangeType.V(503004)
    AGE_RANGE_55_64 = AgeRangeTypeEnum.AgeRangeType.V(503005)
    AGE_RANGE_65_UP = AgeRangeTypeEnum.AgeRangeType.V(503006)
    AGE_RANGE_UNDETERMINED = AgeRangeTypeEnum.AgeRangeType.V(503999)
    def __init__(
        self,
    ) -> None: ...

global___AgeRangeTypeEnum = AgeRangeTypeEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class OperationAccessDeniedErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _OperationAccessDeniedError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            OperationAccessDeniedError.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = OperationAccessDeniedErrorEnum.OperationAccessDeniedError.V(0)
        UNKNOWN = OperationAccessDeniedErrorEnum.OperationAccessDeniedError.V(1)
        ACTION_NOT_PERMITTED = (
            OperationAccessDeniedErrorEnum.OperationAccessDeniedError.V(2)
        )
        CREATE_OPERATION_NOT_PERMITTED = (
            OperationAccessDeniedErrorEnum.OperationAccessDeniedError.V(3)
        )
        REMOVE_OPERATION_NOT_PERMITTED = (
            OperationAccessDeniedErrorEnum.OperationAccessDeniedError.V(4)
        )
        UPDATE_OPERATION_NOT_PERMITTED = (
            OperationAccessDeniedErrorEnum.OperationAccessDeniedError.V(5)
        )
        MUTATE_ACTION_NOT_PERMITTED_FOR_CLIENT = (
            OperationAccessDeniedErrorEnum.OperationAccessDeniedError.V(6)
        )
        OPERATION_NOT_PERMITTED_FOR_CAMPAIGN_TYPE = (
            OperationAccessDeniedErrorEnum.OperationAccessDeniedError.V(7)
        )
        CREATE_AS_REMOVED_NOT_PERMITTED = (
            OperationAccessDeniedErrorEnum.OperationAccessDeniedError.V(8)
        )
        OPERATION_NOT_PERMITTED_FOR_REMOVED_RESOURCE = (
            OperationAccessDeniedErrorEnum.OperationAccessDeniedError.V(9)
        )
        OPERATION_NOT_PERMITTED_FOR_AD_GROUP_TYPE = (
            OperationAccessDeniedErrorEnum.OperationAccessDeniedError.V(10)
        )
        MUTATE_NOT_PERMITTED_FOR_CUSTOMER = (
            OperationAccessDeniedErrorEnum.OperationAccessDeniedError.V(11)
        )
    class OperationAccessDeniedError(metaclass=_OperationAccessDeniedError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = OperationAccessDeniedErrorEnum.OperationAccessDeniedError.V(0)
    UNKNOWN = OperationAccessDeniedErrorEnum.OperationAccessDeniedError.V(1)
    ACTION_NOT_PERMITTED = OperationAccessDeniedErrorEnum.OperationAccessDeniedError.V(
        2
    )
    CREATE_OPERATION_NOT_PERMITTED = (
        OperationAccessDeniedErrorEnum.OperationAccessDeniedError.V(3)
    )
    REMOVE_OPERATION_NOT_PERMITTED = (
        OperationAccessDeniedErrorEnum.OperationAccessDeniedError.V(4)
    )
    UPDATE_OPERATION_NOT_PERMITTED = (
        OperationAccessDeniedErrorEnum.OperationAccessDeniedError.V(5)
    )
    MUTATE_ACTION_NOT_PERMITTED_FOR_CLIENT = (
        OperationAccessDeniedErrorEnum.OperationAccessDeniedError.V(6)
    )
    OPERATION_NOT_PERMITTED_FOR_CAMPAIGN_TYPE = (
        OperationAccessDeniedErrorEnum.OperationAccessDeniedError.V(7)
    )
    CREATE_AS_REMOVED_NOT_PERMITTED = (
        OperationAccessDeniedErrorEnum.OperationAccessDeniedError.V(8)
    )
    OPERATION_NOT_PERMITTED_FOR_REMOVED_RESOURCE = (
        OperationAccessDeniedErrorEnum.OperationAccessDeniedError.V(9)
    )
    OPERATION_NOT_PERMITTED_FOR_AD_GROUP_TYPE = (
        OperationAccessDeniedErrorEnum.OperationAccessDeniedError.V(10)
    )
    MUTATE_NOT_PERMITTED_FOR_CUSTOMER = (
        OperationAccessDeniedErrorEnum.OperationAccessDeniedError.V(11)
    )
    def __init__(
        self,
    ) -> None: ...

global___OperationAccessDeniedErrorEnum = OperationAccessDeniedErrorEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class DomainCategory(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    CAMPAIGN_FIELD_NUMBER: builtins.int
    CATEGORY_FIELD_NUMBER: builtins.int
    LANGUAGE_CODE_FIELD_NUMBER: builtins.int
    DOMAIN_FIELD_NUMBER: builtins.int
    COVERAGE_FRACTION_FIELD_NUMBER: builtins.int
    CATEGORY_RANK_FIELD_NUMBER: builtins.int
    HAS_CHILDREN_FIELD_NUMBER: builtins.int
    RECOMMENDED_CPC_BID_MICROS_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    @property
    def campaign(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def category(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def language_code(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def domain(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def coverage_fraction(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def category_rank(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def has_children(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def recommended_cpc_bid_micros(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        campaign: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        category: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        language_code: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        domain: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        coverage_fraction: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        category_rank: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        has_children: typing.Optional[google.protobuf.wrappers_pb2.BoolValue] = ...,
        recommended_cpc_bid_micros: typing.Optional[
            google.protobuf.wrappers_pb2.Int64Value
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "campaign",
            b"campaign",
            "category",
            b"category",
            "category_rank",
            b"category_rank",
            "coverage_fraction",
            b"coverage_fraction",
            "domain",
            b"domain",
            "has_children",
            b"has_children",
            "language_code",
            b"language_code",
            "recommended_cpc_bid_micros",
            b"recommended_cpc_bid_micros",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "campaign",
            b"campaign",
            "category",
            b"category",
            "category_rank",
            b"category_rank",
            "coverage_fraction",
            b"coverage_fraction",
            "domain",
            b"domain",
            "has_children",
            b"has_children",
            "language_code",
            b"language_code",
            "recommended_cpc_bid_micros",
            b"recommended_cpc_bid_micros",
            "resource_name",
            b"resource_name",
        ],
    ) -> None: ...

global___DomainCategory = DomainCategory



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v6.proto.enums.campaign_shared_set_status_pb2
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CampaignSharedSet(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    CAMPAIGN_FIELD_NUMBER: builtins.int
    SHARED_SET_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    campaign: typing.Text = ...
    shared_set: typing.Text = ...
    status: google.ads.google_ads.v6.proto.enums.campaign_shared_set_status_pb2.CampaignSharedSetStatusEnum.CampaignSharedSetStatus.V = (
        ...
    )
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        campaign: typing.Text = ...,
        shared_set: typing.Text = ...,
        status: google.ads.google_ads.v6.proto.enums.campaign_shared_set_status_pb2.CampaignSharedSetStatusEnum.CampaignSharedSetStatus.V = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_campaign",
            b"_campaign",
            "_shared_set",
            b"_shared_set",
            "campaign",
            b"campaign",
            "shared_set",
            b"shared_set",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_campaign",
            b"_campaign",
            "_shared_set",
            b"_shared_set",
            "campaign",
            b"campaign",
            "resource_name",
            b"resource_name",
            "shared_set",
            b"shared_set",
            "status",
            b"status",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_campaign", b"_campaign"]
    ) -> typing_extensions.Literal["campaign"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_shared_set", b"_shared_set"]
    ) -> typing_extensions.Literal["shared_set"]: ...

global___CampaignSharedSet = CampaignSharedSet



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v4.proto.common.offline_user_data_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class UploadUserDataRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CUSTOMER_ID_FIELD_NUMBER: builtins.int
    OPERATIONS_FIELD_NUMBER: builtins.int
    CUSTOMER_MATCH_USER_LIST_METADATA_FIELD_NUMBER: builtins.int
    customer_id: typing.Text = ...
    @property
    def operations(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___UserDataOperation
    ]: ...
    @property
    def customer_match_user_list_metadata(
        self,
    ) -> google.ads.google_ads.v4.proto.common.offline_user_data_pb2.CustomerMatchUserListMetadata: ...
    def __init__(
        self,
        *,
        customer_id: typing.Text = ...,
        operations: typing.Optional[typing.Iterable[global___UserDataOperation]] = ...,
        customer_match_user_list_metadata: typing.Optional[
            google.ads.google_ads.v4.proto.common.offline_user_data_pb2.CustomerMatchUserListMetadata
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "customer_match_user_list_metadata",
            b"customer_match_user_list_metadata",
            "metadata",
            b"metadata",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "customer_id",
            b"customer_id",
            "customer_match_user_list_metadata",
            b"customer_match_user_list_metadata",
            "metadata",
            b"metadata",
            "operations",
            b"operations",
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["metadata", b"metadata"]
    ) -> typing_extensions.Literal["customer_match_user_list_metadata"]: ...

global___UploadUserDataRequest = UploadUserDataRequest

class UserDataOperation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CREATE_FIELD_NUMBER: builtins.int
    REMOVE_FIELD_NUMBER: builtins.int
    @property
    def create(
        self,
    ) -> google.ads.google_ads.v4.proto.common.offline_user_data_pb2.UserData: ...
    @property
    def remove(
        self,
    ) -> google.ads.google_ads.v4.proto.common.offline_user_data_pb2.UserData: ...
    def __init__(
        self,
        *,
        create: typing.Optional[
            google.ads.google_ads.v4.proto.common.offline_user_data_pb2.UserData
        ] = ...,
        remove: typing.Optional[
            google.ads.google_ads.v4.proto.common.offline_user_data_pb2.UserData
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "create", b"create", "operation", b"operation", "remove", b"remove"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "create", b"create", "operation", b"operation", "remove", b"remove"
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["operation", b"operation"]
    ) -> typing_extensions.Literal["create", "remove"]: ...

global___UserDataOperation = UserDataOperation

class UploadUserDataResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    UPLOAD_DATE_TIME_FIELD_NUMBER: builtins.int
    RECEIVED_OPERATIONS_COUNT_FIELD_NUMBER: builtins.int
    @property
    def upload_date_time(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def received_operations_count(self) -> google.protobuf.wrappers_pb2.Int32Value: ...
    def __init__(
        self,
        *,
        upload_date_time: typing.Optional[
            google.protobuf.wrappers_pb2.StringValue
        ] = ...,
        received_operations_count: typing.Optional[
            google.protobuf.wrappers_pb2.Int32Value
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "received_operations_count",
            b"received_operations_count",
            "upload_date_time",
            b"upload_date_time",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "received_operations_count",
            b"received_operations_count",
            "upload_date_time",
            b"upload_date_time",
        ],
    ) -> None: ...

global___UploadUserDataResponse = UploadUserDataResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v5.proto.enums.app_url_operating_system_type_pb2
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class FinalAppUrl(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    OS_TYPE_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    os_type: google.ads.google_ads.v5.proto.enums.app_url_operating_system_type_pb2.AppUrlOperatingSystemTypeEnum.AppUrlOperatingSystemType.V = (
        ...
    )
    url: typing.Text = ...
    def __init__(
        self,
        *,
        os_type: google.ads.google_ads.v5.proto.enums.app_url_operating_system_type_pb2.AppUrlOperatingSystemTypeEnum.AppUrlOperatingSystemType.V = ...,
        url: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["_url", b"_url", "url", b"url"]
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_url", b"_url", "os_type", b"os_type", "url", b"url"
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_url", b"_url"]
    ) -> typing_extensions.Literal["url"]: ...

global___FinalAppUrl = FinalAppUrl



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class AdGroupFeedErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _AdGroupFeedError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[AdGroupFeedError.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = AdGroupFeedErrorEnum.AdGroupFeedError.V(0)
        UNKNOWN = AdGroupFeedErrorEnum.AdGroupFeedError.V(1)
        FEED_ALREADY_EXISTS_FOR_PLACEHOLDER_TYPE = (
            AdGroupFeedErrorEnum.AdGroupFeedError.V(2)
        )
        CANNOT_CREATE_FOR_REMOVED_FEED = AdGroupFeedErrorEnum.AdGroupFeedError.V(3)
        ADGROUP_FEED_ALREADY_EXISTS = AdGroupFeedErrorEnum.AdGroupFeedError.V(4)
        CANNOT_OPERATE_ON_REMOVED_ADGROUP_FEED = (
            AdGroupFeedErrorEnum.AdGroupFeedError.V(5)
        )
        INVALID_PLACEHOLDER_TYPE = AdGroupFeedErrorEnum.AdGroupFeedError.V(6)
        MISSING_FEEDMAPPING_FOR_PLACEHOLDER_TYPE = (
            AdGroupFeedErrorEnum.AdGroupFeedError.V(7)
        )
        NO_EXISTING_LOCATION_CUSTOMER_FEED = AdGroupFeedErrorEnum.AdGroupFeedError.V(8)
    class AdGroupFeedError(metaclass=_AdGroupFeedError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = AdGroupFeedErrorEnum.AdGroupFeedError.V(0)
    UNKNOWN = AdGroupFeedErrorEnum.AdGroupFeedError.V(1)
    FEED_ALREADY_EXISTS_FOR_PLACEHOLDER_TYPE = AdGroupFeedErrorEnum.AdGroupFeedError.V(
        2
    )
    CANNOT_CREATE_FOR_REMOVED_FEED = AdGroupFeedErrorEnum.AdGroupFeedError.V(3)
    ADGROUP_FEED_ALREADY_EXISTS = AdGroupFeedErrorEnum.AdGroupFeedError.V(4)
    CANNOT_OPERATE_ON_REMOVED_ADGROUP_FEED = AdGroupFeedErrorEnum.AdGroupFeedError.V(5)
    INVALID_PLACEHOLDER_TYPE = AdGroupFeedErrorEnum.AdGroupFeedError.V(6)
    MISSING_FEEDMAPPING_FOR_PLACEHOLDER_TYPE = AdGroupFeedErrorEnum.AdGroupFeedError.V(
        7
    )
    NO_EXISTING_LOCATION_CUSTOMER_FEED = AdGroupFeedErrorEnum.AdGroupFeedError.V(8)
    def __init__(
        self,
    ) -> None: ...

global___AdGroupFeedErrorEnum = AdGroupFeedErrorEnum
